@@ -27,11 +27,11 @@ template<typename T>
 void SetParam(
     util::ParamData& d,
     const std::any& value,
-    const typename std::enable_if<!arma::is_arma_type<T>::value>::type* = 0,
-    const typename std::enable_if<!data::HasSerialize<T>::value>::type* = 0,
-    const typename std::enable_if<!std::is_same<T,
-        std::tuple<mlpack::data::DatasetInfo, arma::mat>>::value>::type* = 0,
-    const typename std::enable_if<!std::is_same<T, bool>::value>::type* = 0)
+    const std::enable_if_t<!arma::is_arma_type<T>::value>* = 0,
+    const std::enable_if_t<!data::HasSerialize<T>::value>* = 0,
+    const std::enable_if_t<!std::is_same_v<T,
+        std::tuple<mlpack::data::DatasetInfo, arma::mat>>>* = 0,
+    const std::enable_if_t<!std::is_same_v<T, bool>>* = 0)
 {
   // No mapping is needed.
   d.value = *std::any_cast<T>(&value);
@@ -44,7 +44,7 @@ template<typename T>
 void SetParam(
     util::ParamData& d,
     const std::any& /* value */,
-    const typename std::enable_if<std::is_same<T, bool>::value>::type* = 0)
+    const std::enable_if_t<std::is_same_v<T, bool>>* = 0)
 {
   // Force set to the value of whether or not this was passed.
   d.value = d.wasPassed;
@@ -58,12 +58,11 @@ template<typename T>
 void SetParam(
     util::ParamData& d,
     const std::any& value,
-    const typename std::enable_if<arma::is_arma_type<T>::value ||
-                                  std::is_same<T,
-        std::tuple<data::DatasetInfo, arma::mat>>::value>::type* = 0)
+    const std::enable_if_t<arma::is_arma_type<T>::value || std::is_same_v<T,
+        std::tuple<data::DatasetInfo, arma::mat>>>* = 0)
 {
   // We're setting the string filename.
-  typedef std::tuple<T, typename ParameterType<T>::type> TupleType;
+  using TupleType = std::tuple<T, typename ParameterType<T>::type>;
   TupleType& tuple = *std::any_cast<TupleType>(&d.value);
   std::get<0>(std::get<1>(tuple)) = std::any_cast<std::string>(value);
 }
@@ -76,11 +75,11 @@ template<typename T>
 void SetParam(
     util::ParamData& d,
     const std::any& value,
-    const typename std::enable_if<!arma::is_arma_type<T>::value>::type* = 0,
-    const typename std::enable_if<data::HasSerialize<T>::value>::type* = 0)
+    const std::enable_if_t<!arma::is_arma_type<T>::value>* = 0,
+    const std::enable_if_t<data::HasSerialize<T>::value>* = 0)
 {
   // We're setting the string filename.
-  typedef std::tuple<T*, typename ParameterType<T>::type> TupleType;
+  using TupleType = std::tuple<T*, typename ParameterType<T>::type>;
   TupleType& tuple = *std::any_cast<TupleType>(&d.value);
   std::get<1>(tuple) = std::any_cast<std::string>(value);
 }
@@ -96,7 +95,7 @@ void SetParam(
 template<typename T>
 void SetParam(util::ParamData& d, const void* input, void* /* output */)
 {
-  SetParam<typename std::remove_pointer<T>::type>(
+  SetParam<std::remove_pointer_t<T>>(
       const_cast<util::ParamData&>(d), *((std::any*) input));
 }
 
