@@ -7,4 +7,4 @@ programs, Go bindings, and C++ classes which can then be integrated into
 larger-scale machine learning solutions.
 
 */
-package mlpack
+package mlpack // import "mlpack.org/v1/mlpack"
