@@ -27,9 +27,6 @@ namespace mlpack {
 namespace bindings {
 namespace julia {
 
-// Defined in mlpack_main.hpp.
-extern std::string programName;
-
 /**
  * The Julia option class.
  */
@@ -50,7 +47,7 @@ class JuliaOption
               const bool required = false,
               const bool input = true,
               const bool noTranspose = false,
-              const std::string& /* testName */ = "")
+              const std::string& bindingName = "")
   {
     // Create the ParamData object to give to IO.
     util::ParamData data;
@@ -64,53 +61,34 @@ class JuliaOption
     data.required = required;
     data.input = input;
     data.loaded = false;
-
-    // Only "verbose" will be persistent.
-    if (identifier == "verbose")
-      data.persistent = true;
-    else
-      data.persistent = false;
     data.cppType = cppName;
 
     // Every parameter we'll get from Julia will have the correct type.
-    data.value = boost::any(defaultValue);
-
-    // Restore the parameters for this program.
-    if (identifier != "verbose")
-      IO::RestoreSettings(programName, false);
+    data.value = defaultValue;
 
     // Set the function pointers that we'll need.  All of these function
     // pointers will be used by both the program that generates the pyx, and
     // also the binding itself.  (The binding itself will only use GetParam,
     // GetPrintableParam, and GetRawParam.)
-    IO::GetSingleton().functionMap[data.tname]["GetParam"] = &GetParam<T>;
-    IO::GetSingleton().functionMap[data.tname]["GetPrintableParam"] =
-        &GetPrintableParam<T>;
+    IO::AddFunction(data.tname, "GetParam", &GetParam<T>);
+    IO::AddFunction(data.tname, "GetPrintableParam", &GetPrintableParam<T>);
 
     // These are used by the jl generator.
-    IO::GetSingleton().functionMap[data.tname]["PrintParamDefn"] =
-        &PrintParamDefn<T>;
-    IO::GetSingleton().functionMap[data.tname]["PrintInputParam"] =
-        &PrintInputParam<T>;
-    IO::GetSingleton().functionMap[data.tname]["PrintOutputProcessing"] =
-        &PrintOutputProcessing<T>;
-    IO::GetSingleton().functionMap[data.tname]["PrintInputProcessing"] =
-        &PrintInputProcessing<T>;
-    IO::GetSingleton().functionMap[data.tname]["PrintDoc"] = &PrintDoc<T>;
-    IO::GetSingleton().functionMap[data.tname]["PrintModelTypeImport"] =
-        &PrintModelTypeImport<T>;
+    IO::AddFunction(data.tname, "PrintParamDefn", &PrintParamDefn<T>);
+    IO::AddFunction(data.tname, "PrintInputParam", &PrintInputParam<T>);
+    IO::AddFunction(data.tname, "PrintOutputProcessing",
+        &PrintOutputProcessing<T>);
+    IO::AddFunction(data.tname, "PrintInputProcessing",
+        &PrintInputProcessing<T>);
+    IO::AddFunction(data.tname, "PrintDoc", &PrintDoc<T>);
+    IO::AddFunction(data.tname, "PrintModelTypeImport",
+        &PrintModelTypeImport<T>);
 
     // This is needed for the Markdown binding output.
-    IO::GetSingleton().functionMap[data.tname]["DefaultParam"] =
-        &DefaultParam<T>;
+    IO::AddFunction(data.tname, "DefaultParam", &DefaultParam<T>);
 
-    // Add the ParamData object, then store.  This is necessary because we may
-    // import more than one .so that uses IO, so we have to keep the options
-    // separate.  programName is a global variable from mlpack_main.hpp.
-    IO::Add(std::move(data));
-    if (identifier != "verbose")
-      IO::StoreSettings(programName);
-    IO::ClearSettings();
+    // Add the ParamData object.
+    IO::AddParameter(bindingName, std::move(data));
   }
 };
 
