@@ -14,33 +14,9 @@
 #define MLPACK_CORE_CV_METRICS_FACILITIES_HPP
 
 #include <mlpack/core.hpp>
-#include <mlpack/core/metrics/lmetric.hpp>
+#include <mlpack/core/distances/lmetric.hpp>
 
 namespace mlpack {
-namespace cv {
-
-/**
-  * Assert there is the same number of the given data points and labels.
-  *
-  * @param data Column-major data.
-  * @param labels Labels.
-  * @param callerDescription A description of the caller that can be used for
-  *     error generation.
-  */
-template<typename DataType>
-void AssertSizes(const DataType& data,
-                 const arma::Row<size_t>& labels,
-                 const std::string& callerDescription)
-{
-  if (data.n_cols != labels.n_elem)
-  {
-    std::ostringstream oss;
-    oss << callerDescription << ": number of points (" << data.n_cols << ") "
-        << "does not match number of labels (" << labels.n_elem << ")!"
-        << std::endl;
-    throw std::invalid_argument(oss.str());
-  }
-}
 
 /**
   * Pairwise distance of the given data.
@@ -48,16 +24,16 @@ void AssertSizes(const DataType& data,
   * @param data Column-major matrix.
   * @param metric Distance metric to be used.
   */
-template<typename DataType, typename Metric>
+template<typename DataType, typename DistanceType>
 DataType PairwiseDistances(const DataType& data,
-                           const Metric& metric)
+                           const DistanceType& distance)
 {
   DataType distances = DataType(data.n_cols, data.n_cols, arma::fill::none);
   for (size_t i = 0; i < data.n_cols; i++)
   {
     for (size_t j = 0; j < i; j++)
     {
-      distances(i, j) = metric.Evaluate(data.col(i), data.col(j));
+      distances(i, j) = distance.Evaluate(data.col(i), data.col(j));
       distances(j, i) = distances(i, j);
     }
   }
@@ -65,7 +41,6 @@ DataType PairwiseDistances(const DataType& data,
   return distances;
 }
 
-} // namespace cv
 } // namespace mlpack
 
 #endif
