@@ -41,12 +41,12 @@ inline bool IsNaNInf(T& val, const std::string& token)
       if (std::numeric_limits<T>::has_infinity)
       {
         val = (!neg) ? std::numeric_limits<T>::infinity() :
-            -std::numeric_limits<T>::infinity();
+            -1 * std::numeric_limits<T>::infinity();
       }
       else
       {
         val = (!neg) ? std::numeric_limits<T>::max() :
-            -std::numeric_limits<T>::max();
+            -1 * std::numeric_limits<T>::max();
       }
 
       return true;
