@@ -1,5 +1,5 @@
 /**
- * @file hpt_impl.hpp
+ * @file core/hpt/hpt_impl.hpp
  * @author Kirill Mishchenko
  *
  * Implementation of hyper-parameter tuning.
@@ -15,7 +15,6 @@
 #include <mlpack/core.hpp>
 
 namespace mlpack {
-namespace hpt {
 
 template<typename MLAlgorithm,
          typename Metric,
@@ -131,8 +130,8 @@ void HyperParameterTuner<MLAlgorithm,
     data::DatasetMapper<data::IncrementPolicy, double>& datasetInfo,
     FixedArgs... fixedArgs)
 {
-  using PreFixedArgT = typename std::remove_reference<
-      typename std::tuple_element<I, ArgsTuple>::type>::type;
+  using PreFixedArgT = std::remove_reference_t<
+      std::tuple_element_t<I, ArgsTuple>>;
   using FixedArgT = FixedArg<typename PreFixedArgT::Type, I>;
 
   InitAndOptimize<I + 1>(args, bestParams, datasetInfo, fixedArgs...,
@@ -244,7 +243,6 @@ TupleType HyperParameterTuner<MLAlgorithm,
   return TupleType(args...);
 }
 
-} // namespace hpt
 } // namespace mlpack
 
 #endif
