@@ -65,7 +65,7 @@ namespace mlpack {
 template<typename DistanceType,
          typename StatisticType = EmptyStatistic,
          typename MatType = arma::mat,
-         template<typename HyperplaneDistanceType>
+         template<typename HyperplaneDistanceType, typename HyperplaneMatType>
             class HyperplaneType = AxisOrthogonalHyperplane,
          template<typename SplitDistanceType, typename SplitMatType>
             class SplitType = MidpointSpaceSplit>
@@ -77,7 +77,7 @@ class SpillTree
   //! The type of element held in MatType.
   using ElemType = typename MatType::elem_type;
   //! The bound type.
-  using BoundType = typename HyperplaneType<DistanceType>::BoundType;
+  using BoundType = typename HyperplaneType<DistanceType, MatType>::BoundType;
 
  private:
   //! The left child node.
@@ -95,7 +95,7 @@ class SpillTree
   //! Flag to distinguish overlapping nodes from non-overlapping nodes.
   bool overlappingNode;
   //! Splitting hyperplane represented by this node.
-  HyperplaneType<DistanceType> hyperplane;
+  HyperplaneType<DistanceType, MatType> hyperplane;
   //! The bound object for this node.
   BoundType bound;
   //! Any extra data contained in the node.
@@ -144,6 +144,13 @@ class SpillTree
   template<typename RuleType>
   using DefeatistDualTreeTraverser = SpillDualTreeTraverser<RuleType, true>;
 
+  /**
+   * A default constructor.  This returns an empty tree, which is not useful.
+   * In general this is only used for serialization or right before copying from
+   * a different object.
+   */
+  SpillTree();
+
   /**
    * Construct this as the root node of a hybrid spill tree using the given
    * dataset.  The dataset will not be modified during the building procedure
@@ -274,7 +281,8 @@ class SpillTree
   bool Overlap() const { return overlappingNode; }
 
   //! Get the Hyperplane instance.
-  const HyperplaneType<DistanceType>& Hyperplane() const { return hyperplane; }
+  const HyperplaneType<DistanceType, MatType>& Hyperplane() const
+      { return hyperplane; }
 
   //! Get the distance metric that the tree uses.
   [[deprecated("Will be removed in mlpack 5.0.0; use Distance()")]]
@@ -438,7 +446,7 @@ class SpillTree
   static bool HasSelfChildren() { return false; }
 
   //! Store the center of the bounding region in the given vector.
-  void Center(arma::vec& center) { bound.Center(center); }
+  void Center(arma::Col<ElemType>& center) { bound.Center(center); }
 
  private:
   /**
@@ -469,17 +477,6 @@ class SpillTree
                    const arma::Col<size_t>& points,
                    arma::Col<size_t>& leftPoints,
                    arma::Col<size_t>& rightPoints);
- protected:
-  /**
-   * A default constructor.  This is meant to only be used with
-   * cereal, which is allowed with the friend declaration below.
-   * This does not return a valid tree!  The method must be protected, so that
-   * the serialization shim can work with the default constructor.
-   */
-  SpillTree();
-
-  //! Friend access is given for the default constructor.
-  friend class cereal::access;
 
  public:
   /**
