@@ -16,15 +16,16 @@ namespace mlpack {
 namespace util {
 
 /**
- * Convert a string to lowercase letters.
- *
- * @param input The string to convert.
- * @param output The string to be converted.
- */
-inline void ToLower(const std::string& input, std::string& output)
+ * Convert a string to lowercase letters.
+ *
+ * @param input The string to convert.
+ */
+inline std::string ToLower(const std::string& input)
 {
-  std::transform(input.begin(), input.end(), output.begin(),
+  std::string output;
+  std::transform(input.begin(), input.end(), std::back_inserter(output),
       [](unsigned char c){ return std::tolower(c); });
+  return output;
 }
 
 } // namespace util
