@@ -12,6 +12,9 @@
 #ifndef MLPACK_METHODS_AMF_SVD_INCOMPLETE_INCREMENTAL_LEARNING_HPP
 #define MLPACK_METHODS_AMF_SVD_INCOMPLETE_INCREMENTAL_LEARNING_HPP
 
+#include <mlpack/prereqs.hpp>
+#include "incremental_iterators.hpp"
+
 namespace mlpack {
 
 /**
@@ -37,6 +40,7 @@ namespace mlpack {
  *
  * @see SVDBatchLearning
  */
+template<typename MatType>
 class SVDIncompleteIncrementalLearning
 {
  public:
@@ -50,7 +54,7 @@ class SVDIncompleteIncrementalLearning
   SVDIncompleteIncrementalLearning(double u = 0.001,
                                    double kw = 0,
                                    double kh = 0)
-          : u(u), kw(kw), kh(kh), currentUserIndex(0)
+          : u(u), kw(kw), kh(kh), currentUserIndex(0), currentItemIndex(0)
   {
     // Nothing to do.
   }
@@ -63,11 +67,9 @@ class SVDIncompleteIncrementalLearning
    * @param * (dataset) Input matrix to be factorized.
    * @param * (rank) of factorization
    */
-  template<typename MatType>
-  void Initialize(const MatType& /* dataset */, const size_t /* rank */)
+  void Initialize(const MatType& dataset, const size_t /* rank */)
   {
-    // Set the current user to 0.
-    currentUserIndex = 0;
+    InitializeVIter(dataset, vIter, currentUserIndex, currentItemIndex);
   }
 
   /**
@@ -79,31 +81,43 @@ class SVDIncompleteIncrementalLearning
    * @param W Basis matrix to be updated.
    * @param H Encoding matrix.
    */
-  template<typename MatType>
+  template<typename WHMatType>
   inline void WUpdate(const MatType& V,
-                      arma::mat& W,
-                      const arma::mat& H)
+                      WHMatType& W,
+                      const WHMatType& H)
   {
-    arma::mat deltaW;
+    WHMatType deltaW;
     deltaW.zeros(V.n_rows, W.n_cols);
 
+    // Store an old copy of the position, because we will need to start from the
+    // same place for the H update step when it is called.
+    typename MatType::const_iterator vIterOld = vIter;
+    const size_t oldUserIndex = currentUserIndex;
+    const size_t oldItemIndex = currentItemIndex;
+
     // Iterate through all the rating by this user to update corresponding item
     // feature feature vector.
-    for (size_t i = 0; i < V.n_rows; ++i)
+    size_t userIndex = currentUserIndex;
+    while (currentUserIndex == userIndex)
     {
-      const double val = V(i, currentUserIndex);
-      // Update only if the rating is non-zero.
-      if (val != 0)
-      {
-        deltaW.row(i) += (val - arma::dot(W.row(i), H.col(currentUserIndex))) *
-            H.col(currentUserIndex).t();
-      }
+      const typename MatType::elem_type val = (*vIter);
+      deltaW.row(currentItemIndex) +=
+          (val - dot(W.row(currentItemIndex), H.col(currentUserIndex))) *
+          H.col(currentUserIndex).t();
+
       // Add regularization.
       if (kw != 0)
-        deltaW.row(i) -= kw * W.row(i);
+        deltaW.row(currentItemIndex) -= kw * W.row(currentItemIndex);
+
+      IncrementVIter(V, vIter, userIndex, currentItemIndex);
     }
 
     W += u * deltaW;
+
+    // Restore position to old position for H update.
+    vIter = vIterOld;
+    currentUserIndex = oldUserIndex;
+    currentItemIndex = oldItemIndex;
   }
 
   /**
@@ -114,33 +128,33 @@ class SVDIncompleteIncrementalLearning
    * @param W Basis matrix.
    * @param H Encoding matrix to be updated.
    */
-  template<typename MatType>
+  template<typename WHMatType>
   inline void HUpdate(const MatType& V,
-                      const arma::mat& W,
-                      arma::mat& H)
+                      const WHMatType& W,
+                      WHMatType& H)
   {
-    arma::vec deltaH;
-    deltaH.zeros(H.n_rows);
+    WHMatType deltaH;
+    deltaH.zeros(H.n_rows, 1);
 
     // Iterate through all the rating by this user to update corresponding item
     // feature feature vector.
-    for (size_t i = 0; i < V.n_rows; ++i)
+    size_t userIndex = currentUserIndex;
+    while (currentUserIndex == userIndex)
     {
-      const double val = V(i, currentUserIndex);
-      // Update only if the rating is non-zero.
-      if (val != 0)
-      {
-        deltaH += (val - arma::dot(W.row(i), H.col(currentUserIndex))) *
-            W.row(i).t();
-      }
+      const typename MatType::elem_type val = (*vIter);
+      deltaH += (val - dot(W.row(currentItemIndex), H.col(currentUserIndex))) *
+          W.row(currentItemIndex).t();
+
+      IncrementVIter(V, vIter, userIndex, currentItemIndex);
     }
+
     // Add regularization.
     if (kh != 0)
       deltaH -= kh * H.col(currentUserIndex);
 
     // Update H matrix and move on to the next user.
-    H.col(currentUserIndex++) += u * deltaH;
-    currentUserIndex = currentUserIndex % V.n_cols;
+    H.col(currentUserIndex) += u * deltaH;
+    currentUserIndex = userIndex;
   }
 
  private:
@@ -151,57 +165,14 @@ class SVDIncompleteIncrementalLearning
   //! Regularization parameter for H matrix.
   double kh;
 
+  //! Iterator pointing to the first nonzero element for the next user.
+  typename MatType::const_iterator vIter;
   //! Current user under consideration.
   size_t currentUserIndex;
+  //! First nonzero item for the given user under consideration.
+  size_t currentItemIndex;
 };
 
-//! TODO : Merge this template specialized function for sparse matrix using
-//!        common row_col_iterator
-
-//! template specialiazed functions for sparse matrices
-template<>
-inline void SVDIncompleteIncrementalLearning::WUpdate<arma::sp_mat>(
-    const arma::sp_mat& V, arma::mat& W, const arma::mat& H)
-{
-  arma::mat deltaW(V.n_rows, W.n_cols);
-  deltaW.zeros();
-  for (arma::sp_mat::const_iterator it = V.begin_col(currentUserIndex);
-      it != V.end_col(currentUserIndex); ++it)
-  {
-    double val = *it;
-    size_t i = it.row();
-    deltaW.row(i) += (val - arma::dot(W.row(i), H.col(currentUserIndex))) *
-        arma::trans(H.col(currentUserIndex));
-    if (kw != 0) deltaW.row(i) -= kw * W.row(i);
-  }
-
-  W += u*deltaW;
-}
-
-template<>
-inline void SVDIncompleteIncrementalLearning::HUpdate<arma::sp_mat>(
-    const arma::sp_mat& V, const arma::mat& W, arma::mat& H)
-{
-  arma::mat deltaH(H.n_rows, 1);
-  deltaH.zeros();
-
-  for (arma::sp_mat::const_iterator it = V.begin_col(currentUserIndex);
-      it != V.end_col(currentUserIndex); ++it)
-  {
-    double val = *it;
-    size_t i = it.row();
-    if ((val = V(i, currentUserIndex)) != 0)
-    {
-      deltaH += (val - arma::dot(W.row(i), H.col(currentUserIndex))) *
-          arma::trans(W.row(i));
-    }
-  }
-  if (kh != 0) deltaH -= kh * H.col(currentUserIndex);
-
-  H.col(currentUserIndex++) += u * deltaH;
-  currentUserIndex = currentUserIndex % V.n_cols;
-}
-
 } // namespace mlpack
 
 #endif
