@@ -16,7 +16,6 @@
 #include <algorithm>
 
 namespace mlpack {
-namespace ann /** Artificial Neural Network. */ {
 
 /**
  * The hard sigmoid function, defined by
@@ -56,17 +55,19 @@ class HardSigmoidFunction
   {
     y.set_size(size(x));
 
-    for (size_t i = 0; i < x.n_elem; ++i)
+    #pragma omp for
+    for (size_t i = 0; i < (size_t) x.n_elem; ++i)
       y(i) = Fn(x(i));
   }
 
   /**
    * Computes the first derivatives of hard sigmoid function.
    *
-   * @param y Input data.
+   * @param x Input activation.
+   * @param y Result of Fn(x).
    * @return f'(x)
    */
-  static double Deriv(const double y)
+  static double Deriv(const double /* x */, const double y)
   {
     if (y == 0.0 || y == 1.0)
     {
@@ -78,22 +79,25 @@ class HardSigmoidFunction
   /**
    * Computes the first derivatives of the hard sigmoid function.
    *
-   * @param y Input data.
-   * @param x The resulting derivatives.
+   * @param x Input activation.
+   * @param y Result of Fn(x).
+   * @param dy The resulting derivatives.
    */
-  template<typename InputVecType, typename OutputVecType>
-  static void Deriv(const InputVecType& y, OutputVecType& x)
+  template<typename InputVecType, typename OutputVecType, typename DerivVecType>
+  static void Deriv(const InputVecType& x,
+                    const OutputVecType& y,
+                    DerivVecType& dy)
   {
-    x.set_size(size(y));
+    dy.set_size(size(y));
 
-    for (size_t i = 0; i < y.n_elem; ++i)
+    #pragma omp for
+    for (size_t i = 0; i < (size_t) y.n_elem; ++i)
     {
-      x(i) = Deriv(y(i));
+      dy(i) = Deriv(x(i), y(i));
     }
   }
 }; // class HardSigmoidFunction
 
-} // namespace ann
 } // namespace mlpack
 
 #endif
