@@ -28,7 +28,6 @@
 #include <mlpack/prereqs.hpp>
 
 namespace mlpack {
-namespace ann /** Artificial Neural Network. */ {
 
 /**
  * The softsign function, defined by
@@ -71,31 +70,35 @@ class SoftsignFunction
   {
     y.set_size(arma::size(x));
 
-    for (size_t i = 0; i < x.n_elem; i++)
+    for (size_t i = 0; i < x.n_elem; ++i)
       y(i) = Fn(x(i));
   }
 
   /**
    * Computes the first derivative of the softsign function.
    *
-   * @param y Input activation.
+   * @param x Input activation.
+   * @param y Result of Fn(x).
    * @return f'(x)
    */
-  static double Deriv(const double y)
+  static double Deriv(const double x, const double /* y */)
   {
-    return std::pow(1.0 - std::abs(y), 2);
+    return 1.0 / std::pow(1.0 + std::abs(x), 2);
   }
 
   /**
    * Computes the first derivatives of the softsign function.
    *
-   * @param y Input activations.
-   * @param x The resulting derivatives.
+   * @param x Input activation.
+   * @param y Result of Fn(x).
+   * @param dy The resulting derivatives.
    */
-  template<typename InputVecType, typename OutputVecType>
-  static void Deriv(const InputVecType& y, OutputVecType& x)
+  template<typename InputVecType, typename OutputVecType, typename DerivVecType>
+  static void Deriv(const InputVecType& x,
+                    const OutputVecType& /* y */,
+                    DerivVecType& dy)
   {
-    x = arma::pow(1.0 - arma::abs(y), 2);
+    dy = 1.0 / pow(1.0 + arma::abs(x), 2);
   }
 
   /**
@@ -123,12 +126,11 @@ class SoftsignFunction
   {
     x.set_size(arma::size(y));
 
-    for (size_t i = 0; i < y.n_elem; i++)
+    for (size_t i = 0; i < y.n_elem; ++i)
       x(i) = Inv(y(i));
   }
 }; // class SoftsignFunction
 
-} // namespace ann
 } // namespace mlpack
 
 #endif
