@@ -37,9 +37,8 @@ double SequencePrecision(arma::field<MatType> trueOutputs,
 
   for (size_t i = 0; i < testSize; ++i)
   {
-    arma::vec delta = arma::vectorise(arma::abs(
-      trueOutputs.at(i) - predOutputs.at(i)));
-    double maxDelta = arma::max(delta);
+    arma::vec delta = vectorise(abs(trueOutputs.at(i) - predOutputs.at(i)));
+    double maxDelta = max(delta);
     if (maxDelta < tol)
     {
       score++;
