@@ -71,14 +71,14 @@ class NguyenWidrowInitialization
    * @param rows Number of rows.
    * @param cols Number of columns.
    */
-  template<typename eT>
-  void Initialize(arma::Mat<eT>& W, const size_t rows, const size_t cols)
+  template<typename MatType>
+  void Initialize(MatType& W, const size_t rows, const size_t cols)
   {
     RandomInitialization randomInit(lowerBound, upperBound);
     randomInit.Initialize(W, rows, cols);
 
     double beta = 0.7 * std::pow(cols, 1.0 / rows);
-    W *= (beta / arma::norm(W));
+    W *= (beta / norm(W));
   }
 
   /**
@@ -87,14 +87,15 @@ class NguyenWidrowInitialization
    *
    * @param W Weight matrix to initialize.
    */
-  template<typename eT>
-  void Initialize(arma::Mat<eT>& W)
+  template<typename MatType>
+  void Initialize(MatType& W,
+      const typename std::enable_if_t<IsMatrix<MatType>::value>* = 0)
   {
     RandomInitialization randomInit(lowerBound, upperBound);
     randomInit.Initialize(W);
 
     double beta = 0.7 * std::pow(W.n_cols, 1.0 / W.n_rows);
-    W *= (beta / arma::norm(W));
+    W *= (beta / norm(W));
   }
 
   /**
@@ -106,8 +107,8 @@ class NguyenWidrowInitialization
    * @param cols Number of columns.
    * @param slices Number of slices.
    */
-  template<typename eT>
-  void Initialize(arma::Cube<eT>& W,
+  template<typename CubeType>
+  void Initialize(CubeType& W,
                   const size_t rows,
                   const size_t cols,
                   const size_t slices)
@@ -125,8 +126,9 @@ class NguyenWidrowInitialization
    *
    * @param W Weight matrix to initialize.
    */
-  template<typename eT>
-  void Initialize(arma::Cube<eT>& W)
+  template<typename CubeType>
+  void Initialize(CubeType& W,
+      const typename std::enable_if_t<IsCube<CubeType>::value>* = 0)
   {
     if (W.is_empty())
       Log::Fatal << "Cannot initialize an empty matrix." << std::endl;
@@ -134,7 +136,7 @@ class NguyenWidrowInitialization
     for (size_t i = 0; i < W.n_slices; ++i)
       Initialize(W.slice(i));
   }
- 
+
   /**
    * Serialize the initialization.
    */
