@@ -119,15 +119,14 @@ void ConcatType<MatType>::Forward(const MatType& input, MatType& output)
   for (size_t i = axis + 1; i < this->outputDimensions.size(); ++i)
     slices *= this->outputDimensions[i];
 
-  std::vector<arma::Cube<typename MatType::elem_type>> layerOutputAliases(
-      this->layerOutputs.size());
+  std::vector<CubeType> layerOutputAliases(this->layerOutputs.size());
   for (size_t i = 0; i < this->layerOutputs.size(); ++i)
   {
     MakeAlias(layerOutputAliases[i], this->layerOutputs[i], rows,
         this->network[i]->OutputDimensions()[axis], slices);
   }
 
-  arma::Cube<typename MatType::elem_type> outputAlias;
+  CubeType outputAlias;
   MakeAlias(outputAlias, output, rows, this->outputDimensions[axis], slices);
 
   // Now get the columns from each output.
@@ -163,7 +162,7 @@ void ConcatType<MatType>::Backward(
   for (size_t i = axis + 1; i < this->outputDimensions.size(); ++i)
     slices *= this->outputDimensions[i];
 
-  arma::Cube<typename MatType::elem_type> gyTmp;
+  CubeType gyTmp;
   MakeAlias(gyTmp, gy, rows, this->outputDimensions[axis], slices);
 
   size_t startCol = 0;
@@ -209,7 +208,7 @@ void ConcatType<MatType>::Backward(
   for (size_t i = axis + 1; i < this->outputDimensions.size(); ++i)
     slices *= this->outputDimensions[i];
 
-  arma::Cube<typename MatType::elem_type> gyTmp;
+  CubeType gyTmp;
   MakeAlias(gyTmp, gy, rows, this->outputDimensions[axis], slices);
 
   size_t startCol = 0;
@@ -243,7 +242,7 @@ void ConcatType<MatType>::Gradient(
   for (size_t i = axis + 1; i < this->outputDimensions.size(); ++i)
     slices *= this->outputDimensions[i];
 
-  arma::Cube<typename MatType::elem_type> errorTmp;
+  CubeType errorTmp;
   MakeAlias(errorTmp, error, rows, this->outputDimensions[axis], slices);
 
   size_t startCol = 0;
@@ -282,7 +281,7 @@ void ConcatType<MatType>::Gradient(
   for (size_t i = axis + 1; i < this->outputDimensions.size(); ++i)
     slices *= this->outputDimensions[i];
 
-  arma::Cube<typename MatType::elem_type> errorTmp;
+  CubeType errorTmp;
   MakeAlias(errorTmp, error, rows, this->outputDimensions[axis], slices);
 
   size_t startCol = 0;
