@@ -13,10 +13,9 @@
 #ifndef MLPACK_METHODS_DET_DTREE_HPP
 #define MLPACK_METHODS_DET_DTREE_HPP
 
-#include <mlpack/prereqs.hpp>
+#include <mlpack/core.hpp>
 
 namespace mlpack {
-namespace det /** Density Estimation Trees */ {
 
 /**
  * A density estimation tree is similar to both a decision tree and a space
@@ -47,11 +46,11 @@ class DTree
 {
  public:
   //! The actual, underlying type we're working with.
-  typedef typename MatType::elem_type  ElemType;
+  using ElemType = typename MatType::elem_type;
   //! The type of vector we are using.
-  typedef typename MatType::vec_type   VecType;
+  using VecType = typename GetColType<MatType>::type;
   //! The statistic type we are holding.
-  typedef typename arma::Col<ElemType> StatType;
+  using StatType = arma::Col<ElemType>;
 
   /**
    * Create an empty density estimation tree.
@@ -223,7 +222,7 @@ class DTree
    */
   bool WithinRange(const VecType& query) const;
 
- private:
+ protected: /* these are checked in the tests */
   // The indices in the complete set of points
   // (after all forms of swapping in the original data
   // matrix to align all the points in a node
@@ -330,9 +329,9 @@ class DTree
    * Serialize the density estimation tree.
    */
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */);
+  void serialize(Archive& ar, const uint32_t /* version */);
 
- private:
+ protected: /* these are checked in the tests */
   // Utility methods.
 
   /**
@@ -357,7 +356,6 @@ class DTree
                    const StatType& maxs);
 };
 
-} // namespace det
 } // namespace mlpack
 
 #include "dtree_impl.hpp"
