@@ -29,7 +29,7 @@ class GiniImpurity
     arma::vec splitCounts(counts.n_cols);
     for (size_t i = 0; i < counts.n_cols; ++i)
     {
-      splitCounts[i] = arma::accu(counts.col(i));
+      splitCounts[i] = accu(counts.col(i));
       numElem += splitCounts[i];
     }
 
@@ -37,7 +37,7 @@ class GiniImpurity
     if (numElem == 0)
       return 0.0;
 
-    arma::Col<size_t> classCounts = arma::sum(counts, 1);
+    arma::Col<size_t> classCounts = sum(counts, 1);
 
     // Calculate the Gini impurity of the un-split node.
     double impurity = 0.0;
