@@ -1,5 +1,5 @@
 /**
- * @file kde_impl.hpp
+ * @file methods/kde/kde_impl.hpp
  * @author Roberto Hueso
  *
  * Implementation of Kernel Density Estimation.
@@ -14,40 +14,17 @@
 #include "kde_rules.hpp"
 
 namespace mlpack {
-namespace kde {
-
-//! Construct tree that rearranges the dataset.
-template<typename TreeType, typename MatType>
-TreeType* BuildTree(
-    MatType&& dataset,
-    std::vector<size_t>& oldFromNew,
-    const typename std::enable_if<
-        tree::TreeTraits<TreeType>::RearrangesDataset>::type* = 0)
-{
-  return new TreeType(std::forward<MatType>(dataset), oldFromNew);
-}
-
-//! Construct tree that doesn't rearrange the dataset.
-template<typename TreeType, typename MatType>
-TreeType* BuildTree(
-    MatType&& dataset,
-    const std::vector<size_t>& /* oldFromNew */,
-    const typename std::enable_if<
-        !tree::TreeTraits<TreeType>::RearrangesDataset>::type* = 0)
-{
-  return new TreeType(std::forward<MatType>(dataset));
-}
 
 template<typename KernelType,
-         typename MetricType,
+         typename DistanceType,
          typename MatType,
-         template<typename TreeMetricType,
+         template<typename TreeDistanceType,
                   typename TreeStatType,
                   typename TreeMatType> class TreeType,
          template<typename> class DualTreeTraversalType,
          template<typename> class SingleTreeTraversalType>
 KDE<KernelType,
-    MetricType,
+    DistanceType,
     MatType,
     TreeType,
     DualTreeTraversalType,
@@ -56,14 +33,14 @@ KDE(const double relError,
     const double absError,
     KernelType kernel,
     const KDEMode mode,
-    MetricType metric,
+    DistanceType distance,
     const bool monteCarlo,
     const double mcProb,
     const size_t initialSampleSize,
     const double mcEntryCoef,
     const double mcBreakCoef) :
     kernel(kernel),
-    metric(metric),
+    distance(distance),
     referenceTree(nullptr),
     oldFromNewReferences(nullptr),
     relError(relError),
@@ -81,22 +58,22 @@ KDE(const double relError,
 }
 
 template<typename KernelType,
-         typename MetricType,
+         typename DistanceType,
          typename MatType,
-         template<typename TreeMetricType,
+         template<typename TreeDistanceType,
                   typename TreeStatType,
                   typename TreeMatType> class TreeType,
          template<typename> class DualTreeTraversalType,
          template<typename> class SingleTreeTraversalType>
 KDE<KernelType,
-    MetricType,
+    DistanceType,
     MatType,
     TreeType,
     DualTreeTraversalType,
     SingleTreeTraversalType>::
 KDE(const KDE& other) :
     kernel(KernelType(other.kernel)),
-    metric(MetricType(other.metric)),
+    distance(DistanceType(other.distance)),
     relError(other.relError),
     absError(other.absError),
     ownsReferenceTree(other.ownsReferenceTree),
@@ -125,22 +102,22 @@ KDE(const KDE& other) :
 }
 
 template<typename KernelType,
-         typename MetricType,
+         typename DistanceType,
          typename MatType,
-         template<typename TreeMetricType,
+         template<typename TreeDistanceType,
                   typename TreeStatType,
                   typename TreeMatType> class TreeType,
          template<typename> class DualTreeTraversalType,
          template<typename> class SingleTreeTraversalType>
 KDE<KernelType,
-    MetricType,
+    DistanceType,
     MatType,
     TreeType,
     DualTreeTraversalType,
     SingleTreeTraversalType>::
 KDE(KDE&& other) :
     kernel(std::move(other.kernel)),
-    metric(std::move(other.metric)),
+    distance(std::move(other.distance)),
     referenceTree(other.referenceTree),
     oldFromNewReferences(other.oldFromNewReferences),
     relError(other.relError),
@@ -155,7 +132,7 @@ KDE(KDE&& other) :
     mcBreakCoef(other.mcBreakCoef)
 {
   other.kernel = std::move(KernelType());
-  other.metric = std::move(MetricType());
+  other.distance = std::move(DistanceType());
   other.referenceTree = nullptr;
   other.oldFromNewReferences = nullptr;
   other.relError = KDEDefaultParams::relError;
@@ -171,63 +148,125 @@ KDE(KDE&& other) :
 }
 
 template<typename KernelType,
-         typename MetricType,
+         typename DistanceType,
          typename MatType,
-         template<typename TreeMetricType,
+         template<typename TreeDistanceType,
                   typename TreeStatType,
                   typename TreeMatType> class TreeType,
          template<typename> class DualTreeTraversalType,
          template<typename> class SingleTreeTraversalType>
 KDE<KernelType,
-    MetricType,
+    DistanceType,
     MatType,
     TreeType,
     DualTreeTraversalType,
     SingleTreeTraversalType>&
 KDE<KernelType,
-    MetricType,
+    DistanceType,
     MatType,
     TreeType,
     DualTreeTraversalType,
     SingleTreeTraversalType>::
-operator=(KDE other)
+operator=(const KDE& other)
 {
-  // Clean memory.
-  if (ownsReferenceTree)
+  if (this != &other)
   {
-    delete referenceTree;
-    delete oldFromNewReferences;
+    // Clean memory.
+    if (ownsReferenceTree)
+    {
+      delete referenceTree;
+      delete oldFromNewReferences;
+    }
+    kernel = KernelType(other.kernel);
+    distance = DistanceType(other.distance);
+    relError = other.relError;
+    absError = other.absError;
+    ownsReferenceTree = other.ownsReferenceTree;
+    trained = other.trained;
+    mode = other.mode;
+    monteCarlo = other.monteCarlo;
+    mcProb = other.mcProb;
+    initialSampleSize = other.initialSampleSize;
+    mcEntryCoef = other.mcEntryCoef;
+    mcBreakCoef = other.mcBreakCoef;
+    if (trained)
+    {
+      if (ownsReferenceTree)
+      {
+        oldFromNewReferences =
+            new std::vector<size_t>(*other.oldFromNewReferences);
+        referenceTree = new Tree(*other.referenceTree);
+      }
+      else
+      {
+        oldFromNewReferences = other.oldFromNewReferences;
+        referenceTree = other.referenceTree;
+      }
+    }
   }
-
-  // Move the other object.
-  this->kernel = std::move(other.kernel);
-  this->metric = std::move(other.metric);
-  this->referenceTree = std::move(other.referenceTree);
-  this->oldFromNewReferences = std::move(other.oldFromNewReferences);
-  this->relError = other.relError;
-  this->absError = other.absError;
-  this->ownsReferenceTree = other.ownsReferenceTree;
-  this->trained = other.trained;
-  this->mode = other.mode;
-  this->monteCarlo = other.monteCarlo;
-  this->mcProb = other.mcProb;
-  this->initialSampleSize = other.initialSampleSize;
-  this->mcEntryCoef = other.mcEntryCoef;
-  this->mcBreakCoef = other.mcBreakCoef;
-
   return *this;
 }
 
 template<typename KernelType,
-         typename MetricType,
+         typename DistanceType,
          typename MatType,
-         template<typename TreeMetricType,
+         template<typename TreeDistanceType,
                   typename TreeStatType,
                   typename TreeMatType> class TreeType,
          template<typename> class DualTreeTraversalType,
          template<typename> class SingleTreeTraversalType>
 KDE<KernelType,
-    MetricType,
+    DistanceType,
+    MatType,
+    TreeType,
+    DualTreeTraversalType,
+    SingleTreeTraversalType>&
+KDE<KernelType,
+    DistanceType,
+    MatType,
+    TreeType,
+    DualTreeTraversalType,
+    SingleTreeTraversalType>::
+operator=(KDE&& other)
+{
+  if (this != &other)
+  {
+    // Clean memory.
+    if (ownsReferenceTree)
+    {
+      delete referenceTree;
+      delete oldFromNewReferences;
+    }
+
+    // Move the other object.
+    this->kernel = std::move(other.kernel);
+    this->distance = std::move(other.distance);
+    this->referenceTree = std::move(other.referenceTree);
+    this->oldFromNewReferences = std::move(other.oldFromNewReferences);
+    this->relError = other.relError;
+    this->absError = other.absError;
+    this->ownsReferenceTree = other.ownsReferenceTree;
+    this->trained = other.trained;
+    this->mode = other.mode;
+    this->monteCarlo = other.monteCarlo;
+    this->mcProb = other.mcProb;
+    this->initialSampleSize = other.initialSampleSize;
+    this->mcEntryCoef = other.mcEntryCoef;
+    this->mcBreakCoef = other.mcBreakCoef;
+  }
+  return *this;
+}
+
+template<typename KernelType,
+         typename DistanceType,
+         typename MatType,
+         template<typename TreeDistanceType,
+                  typename TreeStatType,
+                  typename TreeMatType> class TreeType,
+         template<typename> class DualTreeTraversalType,
+         template<typename> class SingleTreeTraversalType>
+KDE<KernelType,
+    DistanceType,
     MatType,
     TreeType,
     DualTreeTraversalType,
@@ -242,15 +281,15 @@ KDE<KernelType,
 }
 
 template<typename KernelType,
-         typename MetricType,
+         typename DistanceType,
          typename MatType,
-         template<typename TreeMetricType,
+         template<typename TreeDistanceType,
                   typename TreeStatType,
                   typename TreeMatType> class TreeType,
          template<typename> class DualTreeTraversalType,
          template<typename> class SingleTreeTraversalType>
 void KDE<KernelType,
-         MetricType,
+         DistanceType,
          MatType,
          TreeType,
          DualTreeTraversalType,
@@ -271,24 +310,22 @@ Train(MatType referenceSet)
   }
 
   this->ownsReferenceTree = true;
-  Timer::Start("building_reference_tree");
   this->oldFromNewReferences = new std::vector<size_t>;
   this->referenceTree = BuildTree<Tree>(std::move(referenceSet),
                                         *oldFromNewReferences);
-  Timer::Stop("building_reference_tree");
   this->trained = true;
 }
 
 template<typename KernelType,
-         typename MetricType,
+         typename DistanceType,
          typename MatType,
-         template<typename TreeMetricType,
+         template<typename TreeDistanceType,
                   typename TreeStatType,
                   typename TreeMatType> class TreeType,
          template<typename> class DualTreeTraversalType,
          template<typename> class SingleTreeTraversalType>
 void KDE<KernelType,
-         MetricType,
+         DistanceType,
          MatType,
          TreeType,
          DualTreeTraversalType,
@@ -315,27 +352,25 @@ Train(Tree* referenceTree, std::vector<size_t>* oldFromNewReferences)
 }
 
 template<typename KernelType,
-         typename MetricType,
+         typename DistanceType,
          typename MatType,
-         template<typename TreeMetricType,
+         template<typename TreeDistanceType,
                   typename TreeStatType,
                   typename TreeMatType> class TreeType,
          template<typename> class DualTreeTraversalType,
          template<typename> class SingleTreeTraversalType>
 void KDE<KernelType,
-         MetricType,
+         DistanceType,
          MatType,
          TreeType,
          DualTreeTraversalType,
          SingleTreeTraversalType>::
 Evaluate(MatType querySet, arma::vec& estimations)
 {
-  if (mode == DUAL_TREE_MODE)
+  if (mode == KDE_DUAL_TREE_MODE)
   {
-    Timer::Start("building_query_tree");
     std::vector<size_t> oldFromNewQueries;
     Tree* queryTree = BuildTree<Tree>(std::move(querySet), oldFromNewQueries);
-    Timer::Stop("building_query_tree");
     try
     {
       this->Evaluate(queryTree, oldFromNewQueries, estimations);
@@ -348,7 +383,7 @@ Evaluate(MatType querySet, arma::vec& estimations)
     }
     delete queryTree;
   }
-  else if (mode == SINGLE_TREE_MODE)
+  else if (mode == KDE_SINGLE_TREE_MODE)
   {
     // Get estimations vector ready.
     estimations.clear();
@@ -377,10 +412,8 @@ Evaluate(MatType querySet, arma::vec& estimations)
                                   "referenceSet dimensions don't match");
     }
 
-    Timer::Start("computing_kde");
-
     // Evaluate.
-    typedef KDERules<MetricType, KernelType, Tree> RuleType;
+    using RuleType = KDERules<DistanceType, KernelType, Tree>;
     RuleType rules = RuleType(referenceTree->Dataset(),
                               querySet,
                               estimations,
@@ -390,7 +423,7 @@ Evaluate(MatType querySet, arma::vec& estimations)
                               initialSampleSize,
                               mcEntryCoef,
                               mcBreakCoef,
-                              metric,
+                              distance,
                               kernel,
                               monteCarlo,
                               false);
@@ -403,7 +436,6 @@ Evaluate(MatType querySet, arma::vec& estimations)
       traverser.Traverse(i, *referenceTree);
 
     estimations /= referenceTree->Dataset().n_cols;
-    Timer::Stop("computing_kde");
 
     Log::Info << rules.Scores() << " node combinations were scored."
               << std::endl;
@@ -413,15 +445,15 @@ Evaluate(MatType querySet, arma::vec& estimations)
 }
 
 template<typename KernelType,
-         typename MetricType,
+         typename DistanceType,
          typename MatType,
-         template<typename TreeMetricType,
+         template<typename TreeDistanceType,
                   typename TreeStatType,
                   typename TreeMatType> class TreeType,
          template<typename> class DualTreeTraversalType,
          template<typename> class SingleTreeTraversalType>
 void KDE<KernelType,
-         MetricType,
+         DistanceType,
          MatType,
          TreeType,
          DualTreeTraversalType,
@@ -458,7 +490,7 @@ Evaluate(Tree* queryTree,
   }
 
   // Check the mode is correct.
-  if (mode != DUAL_TREE_MODE)
+  if (mode != KDE_DUAL_TREE_MODE)
   {
     throw std::invalid_argument("cannot evaluate KDE model: cannot use "
                                 "a query tree when mode is different from "
@@ -466,19 +498,15 @@ Evaluate(Tree* queryTree,
   }
 
   // Clean accumulated alpha if Monte Carlo estimations are available.
-  if (monteCarlo && std::is_same<KernelType, kernel::GaussianKernel>::value)
+  if (monteCarlo && std::is_same_v<KernelType, GaussianKernel>)
   {
-    Timer::Start("cleaning_query_tree");
     KDECleanRules<Tree> cleanRules;
     SingleTreeTraversalType<KDECleanRules<Tree>> cleanTraverser(cleanRules);
     cleanTraverser.Traverse(0, *queryTree);
-    Timer::Stop("cleaning_query_tree");
   }
 
-  Timer::Start("computing_kde");
-
   // Evaluate.
-  typedef KDERules<MetricType, KernelType, Tree> RuleType;
+  using RuleType = KDERules<DistanceType, KernelType, Tree>;
   RuleType rules = RuleType(referenceTree->Dataset(),
                             queryTree->Dataset(),
                             estimations,
@@ -488,7 +516,7 @@ Evaluate(Tree* queryTree,
                             initialSampleSize,
                             mcEntryCoef,
                             mcBreakCoef,
-                            metric,
+                            distance,
                             kernel,
                             monteCarlo,
                             false);
@@ -497,7 +525,6 @@ Evaluate(Tree* queryTree,
   DualTreeTraversalType<RuleType> traverser(rules);
   traverser.Traverse(*queryTree, *referenceTree);
   estimations /= referenceTree->Dataset().n_cols;
-  Timer::Stop("computing_kde");
 
   // Rearrange if necessary.
   RearrangeEstimations(oldFromNewQueries, estimations);
@@ -507,15 +534,15 @@ Evaluate(Tree* queryTree,
 }
 
 template<typename KernelType,
-         typename MetricType,
+         typename DistanceType,
          typename MatType,
-         template<typename TreeMetricType,
+         template<typename TreeDistanceType,
                   typename TreeStatType,
                   typename TreeMatType> class TreeType,
          template<typename> class DualTreeTraversalType,
          template<typename> class SingleTreeTraversalType>
 void KDE<KernelType,
-         MetricType,
+         DistanceType,
          MatType,
          TreeType,
          DualTreeTraversalType,
@@ -535,19 +562,15 @@ Evaluate(arma::vec& estimations)
   estimations.fill(arma::fill::zeros);
 
   // Clean accumulated alpha if Monte Carlo estimations are available.
-  if (monteCarlo && std::is_same<KernelType, kernel::GaussianKernel>::value)
+  if (monteCarlo && std::is_same_v<KernelType, GaussianKernel>)
   {
-    Timer::Start("cleaning_query_tree");
     KDECleanRules<Tree> cleanRules;
     SingleTreeTraversalType<KDECleanRules<Tree>> cleanTraverser(cleanRules);
     cleanTraverser.Traverse(0, *referenceTree);
-    Timer::Stop("cleaning_query_tree");
   }
 
-  Timer::Start("computing_kde");
-
   // Evaluate.
-  typedef KDERules<MetricType, KernelType, Tree> RuleType;
+  using RuleType = KDERules<DistanceType, KernelType, Tree>;
   RuleType rules = RuleType(referenceTree->Dataset(),
                             referenceTree->Dataset(),
                             estimations,
@@ -557,18 +580,18 @@ Evaluate(arma::vec& estimations)
                             initialSampleSize,
                             mcEntryCoef,
                             mcBreakCoef,
-                            metric,
+                            distance,
                             kernel,
                             monteCarlo,
                             true);
 
-  if (mode == DUAL_TREE_MODE)
+  if (mode == KDE_DUAL_TREE_MODE)
   {
     // Create traverser.
     DualTreeTraversalType<RuleType> traverser(rules);
     traverser.Traverse(*referenceTree, *referenceTree);
   }
-  else if (mode == SINGLE_TREE_MODE)
+  else if (mode == KDE_SINGLE_TREE_MODE)
   {
     SingleTreeTraversalType<RuleType> traverser(rules);
     for (size_t i = 0; i < referenceTree->Dataset().n_cols; ++i)
@@ -578,22 +601,21 @@ Evaluate(arma::vec& estimations)
   estimations /= referenceTree->Dataset().n_cols;
   // Rearrange if necessary.
   RearrangeEstimations(*oldFromNewReferences, estimations);
-  Timer::Stop("computing_kde");
 
   Log::Info << rules.Scores() << " node combinations were scored." << std::endl;
   Log::Info << rules.BaseCases() << " base cases were calculated." << std::endl;
 }
 
 template<typename KernelType,
-         typename MetricType,
+         typename DistanceType,
          typename MatType,
-         template<typename TreeMetricType,
+         template<typename TreeDistanceType,
                   typename TreeStatType,
                   typename TreeMatType> class TreeType,
          template<typename> class DualTreeTraversalType,
          template<typename> class SingleTreeTraversalType>
 void KDE<KernelType,
-         MetricType,
+         DistanceType,
          MatType,
          TreeType,
          DualTreeTraversalType,
@@ -605,15 +627,15 @@ RelativeError(const double newError)
 }
 
 template<typename KernelType,
-         typename MetricType,
+         typename DistanceType,
          typename MatType,
-         template<typename TreeMetricType,
+         template<typename TreeDistanceType,
                   typename TreeStatType,
                   typename TreeMatType> class TreeType,
          template<typename> class DualTreeTraversalType,
          template<typename> class SingleTreeTraversalType>
 void KDE<KernelType,
-         MetricType,
+         DistanceType,
          MatType,
          TreeType,
          DualTreeTraversalType,
@@ -625,15 +647,15 @@ AbsoluteError(const double newError)
 }
 
 template<typename KernelType,
-         typename MetricType,
+         typename DistanceType,
          typename MatType,
-         template<typename TreeMetricType,
+         template<typename TreeDistanceType,
                   typename TreeStatType,
                   typename TreeMatType> class TreeType,
          template<typename> class DualTreeTraversalType,
          template<typename> class SingleTreeTraversalType>
 void KDE<KernelType,
-         MetricType,
+         DistanceType,
          MatType,
          TreeType,
          DualTreeTraversalType,
@@ -650,15 +672,15 @@ MCProb(const double newProb)
 }
 
 template<typename KernelType,
-         typename MetricType,
+         typename DistanceType,
          typename MatType,
-         template<typename TreeMetricType,
+         template<typename TreeDistanceType,
                   typename TreeStatType,
                   typename TreeMatType> class TreeType,
          template<typename> class DualTreeTraversalType,
          template<typename> class SingleTreeTraversalType>
 void KDE<KernelType,
-         MetricType,
+         DistanceType,
          MatType,
          TreeType,
          DualTreeTraversalType,
@@ -674,15 +696,15 @@ MCEntryCoef(const double newCoef)
 }
 
 template<typename KernelType,
-         typename MetricType,
+         typename DistanceType,
          typename MatType,
-         template<typename TreeMetricType,
+         template<typename TreeDistanceType,
                   typename TreeStatType,
                   typename TreeMatType> class TreeType,
          template<typename> class DualTreeTraversalType,
          template<typename> class SingleTreeTraversalType>
 void KDE<KernelType,
-         MetricType,
+         DistanceType,
          MatType,
          TreeType,
          DualTreeTraversalType,
@@ -698,49 +720,35 @@ MCBreakCoef(const double newCoef)
 }
 
 template<typename KernelType,
-         typename MetricType,
+         typename DistanceType,
          typename MatType,
-         template<typename TreeMetricType,
+         template<typename TreeDistanceType,
                   typename TreeStatType,
                   typename TreeMatType> class TreeType,
          template<typename> class DualTreeTraversalType,
          template<typename> class SingleTreeTraversalType>
 template<typename Archive>
 void KDE<KernelType,
-         MetricType,
+         DistanceType,
          MatType,
          TreeType,
          DualTreeTraversalType,
          SingleTreeTraversalType>::
-serialize(Archive& ar, const unsigned int version)
+serialize(Archive& ar, const uint32_t /* version */)
 {
   // Serialize preferences.
-  ar & BOOST_SERIALIZATION_NVP(relError);
-  ar & BOOST_SERIALIZATION_NVP(absError);
-  ar & BOOST_SERIALIZATION_NVP(trained);
-  ar & BOOST_SERIALIZATION_NVP(mode);
-
-  // Backward compatibility: Old versions of KDE did not need to handle Monte
-  // Carlo parameters.
-  if (version > 0)
-  {
-    ar & BOOST_SERIALIZATION_NVP(monteCarlo);
-    ar & BOOST_SERIALIZATION_NVP(mcProb);
-    ar & BOOST_SERIALIZATION_NVP(initialSampleSize);
-    ar & BOOST_SERIALIZATION_NVP(mcEntryCoef);
-    ar & BOOST_SERIALIZATION_NVP(mcBreakCoef);
-  }
-  else if (Archive::is_loading::value)
-  {
-    monteCarlo = KDEDefaultParams::monteCarlo;
-    mcProb = KDEDefaultParams::mcProb;
-    initialSampleSize = KDEDefaultParams::initialSampleSize;
-    mcEntryCoef = KDEDefaultParams::mcEntryCoef;
-    mcBreakCoef = KDEDefaultParams::mcBreakCoef;
-  }
+  ar(CEREAL_NVP(relError));
+  ar(CEREAL_NVP(absError));
+  ar(CEREAL_NVP(trained));
+  ar(CEREAL_NVP(mode));
+  ar(CEREAL_NVP(monteCarlo));
+  ar(CEREAL_NVP(mcProb));
+  ar(CEREAL_NVP(initialSampleSize));
+  ar(CEREAL_NVP(mcEntryCoef));
+  ar(CEREAL_NVP(mcBreakCoef));
 
   // If we are loading, clean up memory if necessary.
-  if (Archive::is_loading::value)
+  if (cereal::is_loading<Archive>())
   {
     if (ownsReferenceTree && referenceTree)
     {
@@ -752,22 +760,22 @@ serialize(Archive& ar, const unsigned int version)
   }
 
   // Serialize the rest of values.
-  ar & BOOST_SERIALIZATION_NVP(kernel);
-  ar & BOOST_SERIALIZATION_NVP(metric);
-  ar & BOOST_SERIALIZATION_NVP(referenceTree);
-  ar & BOOST_SERIALIZATION_NVP(oldFromNewReferences);
+  ar(CEREAL_NVP(kernel));
+  ar(CEREAL_NVP(distance));
+  ar(CEREAL_POINTER(referenceTree));
+  ar(CEREAL_POINTER(oldFromNewReferences));
 }
 
 template<typename KernelType,
-         typename MetricType,
+         typename DistanceType,
          typename MatType,
-         template<typename TreeMetricType,
+         template<typename TreeDistanceType,
                   typename TreeStatType,
                   typename TreeMatType> class TreeType,
          template<typename> class DualTreeTraversalType,
          template<typename> class SingleTreeTraversalType>
 void KDE<KernelType,
-         MetricType,
+         DistanceType,
          MatType,
          TreeType,
          DualTreeTraversalType,
@@ -787,15 +795,15 @@ CheckErrorValues(const double relError, const double absError)
 }
 
 template<typename KernelType,
-         typename MetricType,
+         typename DistanceType,
          typename MatType,
-         template<typename TreeMetricType,
+         template<typename TreeDistanceType,
                   typename TreeStatType,
                   typename TreeMatType> class TreeType,
          template<typename> class DualTreeTraversalType,
          template<typename> class SingleTreeTraversalType>
 void KDE<KernelType,
-         MetricType,
+         DistanceType,
          MatType,
          TreeType,
          DualTreeTraversalType,
@@ -803,7 +811,7 @@ void KDE<KernelType,
 RearrangeEstimations(const std::vector<size_t>& oldFromNew,
                      arma::vec& estimations)
 {
-  if (tree::TreeTraits<Tree>::RearrangesDataset)
+  if (TreeTraits<Tree>::RearrangesDataset)
   {
     const size_t nQueries = oldFromNew.size();
     arma::vec rearrangedEstimations(nQueries);
@@ -816,5 +824,4 @@ RearrangeEstimations(const std::vector<size_t>& oldFromNew,
   }
 }
 
-} // namespace kde
 } // namespace mlpack
