@@ -19,7 +19,6 @@
 #include <mlpack/core/math/shuffle_data.hpp>
 
 namespace mlpack {
-namespace regression {
 
 /**
  * The log-likelihood function for the logistic regression objective function.
@@ -41,24 +40,6 @@ class LogisticRegressionFunction
                              const arma::Row<size_t>& responses,
                              const double lambda = 0);
 
-  /**
-   * Creates the LogisticRegressionFunction with initialPoint.
-   *
-   * @param predictors The matrix of data points.
-   * @param responses The measured data for each point in predictors.
-   * @param initialPoint Point from which to start the optimization.
-   * @param lambda Regularization constant for ridge regression.
-   */
-  LogisticRegressionFunction(const MatType& predictors,
-                             const arma::Row<size_t>& responses,
-                             const arma::vec& initialPoint,
-                             const double lambda = 0);
-
-  //! Return the initial point for the optimization.
-  const arma::mat& InitialPoint() const { return initialPoint; }
-  //! Modify the initial point for the optimization.
-  arma::mat& InitialPoint() { return initialPoint; }
-
   //! Return the regularization parameter (lambda).
   const double& Lambda() const { return lambda; }
   //! Modify the regularization parameter (lambda).
@@ -70,7 +51,8 @@ class LogisticRegressionFunction
   const arma::Row<size_t>& Responses() const { return responses; }
 
   /**
-  * Shuffle the order of function visitation.  This may be called by the optimizer.
+  * Shuffle the order of function visitation.  This may be called by the
+  * optimizer.
   */
   void Shuffle();
 
@@ -85,7 +67,9 @@ class LogisticRegressionFunction
    *
    * @param parameters Vector of logistic regression parameters.
    */
-  double Evaluate(const arma::mat& parameters) const;
+  template<typename CoordinatesType>
+  typename CoordinatesType::elem_type Evaluate(
+      const CoordinatesType& parameters) const;
 
   /**
    * Evaluate the logistic regression log-likelihood function with the given
@@ -104,9 +88,11 @@ class LogisticRegressionFunction
    * @param batchSize Number of points to be passed at a time to use for
    *     objective function evaluation.
    */
-  double Evaluate(const arma::mat& parameters,
-                  const size_t begin,
-                  const size_t batchSize = 1) const;
+  template<typename CoordinatesType>
+  typename CoordinatesType::elem_type Evaluate(
+      const CoordinatesType& parameters,
+      const size_t begin,
+      const size_t batchSize = 1) const;
 
   /**
    * Evaluate the gradient of the logistic regression log-likelihood function
@@ -115,7 +101,8 @@ class LogisticRegressionFunction
    * @param parameters Vector of logistic regression parameters.
    * @param gradient Vector to output gradient into.
    */
-  void Gradient(const arma::mat& parameters, arma::mat& gradient) const;
+  template<typename CoordinatesType, typename GradType>
+  void Gradient(const CoordinatesType& parameters, GradType& gradient) const;
 
   /**
    * Evaluate the gradient of the logistic regression log-likelihood function
@@ -130,8 +117,8 @@ class LogisticRegressionFunction
    * @param batchSize Number of points to be processed as a batch for objective
    *     function gradient evaluation.
    */
-  template<typename GradType>
-  void Gradient(const arma::mat& parameters,
+  template<typename CoordinatesType, typename GradType>
+  void Gradient(const CoordinatesType& parameters,
                 const size_t begin,
                 GradType& gradient,
                 const size_t batchSize = 1) const;
@@ -145,33 +132,33 @@ class LogisticRegressionFunction
    * @param parameters Vector of logistic regression parameters.
    * @param j Index of the feature with respect to which the gradient is to
    *    be computed.
-   * @param gradient Sparse matrix to output gradient into.
+   * @param gradient Matrix to output gradient into.
    */
-  void PartialGradient(const arma::mat& parameters,
+  template<typename CoordinatesType, typename GradType>
+  void PartialGradient(const CoordinatesType& parameters,
                        const size_t j,
-                       arma::sp_mat& gradient) const;
+                       GradType& gradient) const;
 
   /**
    * Evaluate the objective function and gradient of the logistic regression
    * log-likelihood function simultaneously with the given parameters.
    */
-  template<typename GradType>
-  double EvaluateWithGradient(const arma::mat& parameters,
-                              GradType& gradient) const;
+  template<typename CoordinatesType, typename GradType>
+  typename CoordinatesType::elem_type EvaluateWithGradient(
+      const CoordinatesType& parameters,
+      GradType& gradient) const;
 
   /**
    * Evaluate the objective function and gradient of the logistic regression
    * log-likelihood function simultaneously with the given parameters, for
    * the given batch size from a given point in the dataset.
    */
-  template<typename GradType>
-  double EvaluateWithGradient(const arma::mat& parameters,
-                              const size_t begin,
-                              GradType& gradient,
-                              const size_t batchSize = 1) const;
-
-  //! Return the initial point for the optimization.
-  const arma::mat& GetInitialPoint() const { return initialPoint; }
+  template<typename CoordinatesType, typename GradType>
+  typename CoordinatesType::elem_type EvaluateWithGradient(
+      const CoordinatesType& parameters,
+      const size_t begin,
+      GradType& gradient,
+      const size_t batchSize = 1) const;
 
   //! Return the number of separable functions (the number of predictor points).
   size_t NumFunctions() const { return predictors.n_cols; }
@@ -180,8 +167,6 @@ class LogisticRegressionFunction
   size_t NumFeatures() const { return predictors.n_rows + 1; }
 
  private:
-  //! The initial point, from which to start the optimization.
-  arma::mat initialPoint;
   //! The matrix of data points (predictors).  This is an alias until shuffling
   //! is done.
   MatType predictors;
@@ -192,7 +177,6 @@ class LogisticRegressionFunction
   double lambda;
 };
 
-} // namespace regression
 } // namespace mlpack
 
 // Include implementation.
