@@ -133,7 +133,7 @@ class SparseAutoencoder
    */
   void Sigmoid(const arma::mat& x, arma::mat& output) const
   {
-    output = (1.0 / (1 + arma::exp(-x)));
+    output = (1.0 / (1 + exp(-x)));
   }
 
   //! Sets size of the visible layer.
