@@ -85,12 +85,13 @@ BINDING_SEE_ALSO("@local_coordinate_coding", "#local_coordinate_coding");
 BINDING_SEE_ALSO("Sparse dictionary learning on Wikipedia",
     "https://en.wikipedia.org/wiki/Sparse_dictionary_learning");
 BINDING_SEE_ALSO("Efficient sparse coding algorithms (pdf)",
-    "http://papers.nips.cc/paper/2979-efficient-sparse-coding-algorithms.pdf");
+    "https://proceedings.neurips.cc/paper_files/paper/2006/file/"
+    "2d71b2ae158c7c5912cc0bbde2bb9d95-Paper.pdf");
 BINDING_SEE_ALSO("Regularization and variable selection via the elastic net",
-    "http://citeseerx.ist.psu.edu/viewdoc/download?doi=10.1.1.124.4696&rep=rep1"
-    "&type=pdf");
+    "https://citeseerx.ist.psu.edu/document?repid=rep1&type=pdf"
+    "&doi=46217f372a75dddc2254fdbc6b9418ba3554e453");
 BINDING_SEE_ALSO("SparseCoding C++ class documentation",
-    "@src/mlpack/methods/sparse_coding/sparse_coding.hpp");
+    "@doc/user/methods/sparse_coding.md");
 
 // Train the model.
 PARAM_MATRIX_IN("training", "Matrix of training data (X).", "t");
@@ -113,9 +114,9 @@ PARAM_DOUBLE_IN("newton_tolerance", "Tolerance for convergence of Newton "
     "method.", "w", 1e-6);
 
 // Load/save a model.
-PARAM_MODEL_IN(SparseCoding, "input_model", "File containing input sparse "
+PARAM_MODEL_IN(SparseCoding<>, "input_model", "File containing input sparse "
     "coding model.", "m");
-PARAM_MODEL_OUT(SparseCoding, "output_model", "File to save trained sparse "
+PARAM_MODEL_OUT(SparseCoding<>, "output_model", "File to save trained sparse "
     "coding model to.", "M");
 
 PARAM_MATRIX_OUT("dictionary", "Matrix to save the output dictionary to.", "d");
@@ -177,11 +178,11 @@ void BINDING_FUNCTION(util::Params& params, util::Timers& timers)
       "Newton method tolerance must be nonnegative");
 
   // Do we have an existing model?
-  SparseCoding* sc;
+  SparseCoding<>* sc;
   if (params.Has("input_model"))
-    sc = params.Get<SparseCoding*>("input_model");
+    sc = params.Get<SparseCoding<>*>("input_model");
   else
-    sc = new SparseCoding(0, 0.0);
+    sc = new SparseCoding<>(0, 0.0);
 
   if (params.Has("training"))
   {
@@ -207,7 +208,7 @@ void BINDING_FUNCTION(util::Params& params, util::Timers& timers)
     if (params.Has("input_model"))
     {
       Log::Info << "Using dictionary from existing model in '"
-          << params.GetPrintable<SparseCoding>("input_model")
+          << params.GetPrintable<SparseCoding<>>("input_model")
           << "' as initial dictionary for training." << endl;
       sc->Train<NothingInitializer>(matX);
     }
@@ -286,5 +287,5 @@ void BINDING_FUNCTION(util::Params& params, util::Timers& timers)
       sc->Dictionary().n_rows, sc->Dictionary().n_cols, false, false);
 
   // Save the model.
-  params.Get<SparseCoding*>("output_model") = sc;
+  params.Get<SparseCoding<>*>("output_model") = sc;
 }
