@@ -975,7 +975,7 @@ TEMPLATE_TEST_CASE("AdaBoostSinglePointClassify", "[AdaBoostTest]", mat, fmat)
   // Create random data.
   MatType data = randu<MatType>(10, 100);
   // Create random labels.
-  Row<size_t> labels = randi<Row<size_t>>(100, distr_param(0, 3));
+  Row<size_t> labels = randi<Row<size_t>>(100, DistrParam(0, 3));
 
   // Train a model.
   using PerceptronType =
@@ -1000,7 +1000,7 @@ TEMPLATE_TEST_CASE("AdaBoostSinglePointClassifyWithProbs", "[AdaBoostTest]",
   // Create random data.
   MatType data = randu<MatType>(10, 100);
   // Create random labels.
-  Row<size_t> labels = randi<Row<size_t>>(100, distr_param(0, 3));
+  Row<size_t> labels = randi<Row<size_t>>(100, DistrParam(0, 3));
 
   // Train a model.
   using PerceptronType =
@@ -1066,7 +1066,7 @@ TEMPLATE_TEST_CASE("AdaBoostTrainOverloads", "[AdaBoostTest]", fmat, mat)
   // Create random data.
   MatType data = randu<MatType>(10, 100);
   // Create random labels.
-  Row<size_t> labels = randi<Row<size_t>>(100, distr_param(0, 3));
+  Row<size_t> labels = randi<Row<size_t>>(100, DistrParam(0, 3));
 
   using PerceptronType =
       Perceptron<SimpleWeightUpdate, ZeroInitialization, MatType>;
