@@ -47,13 +47,13 @@ TEST_CASE("AdaptiveMeanPoolingTestCase", "[ANNLayerTest]")
   module1.ComputeOutputDimensions();
   module1.Forward(input, output);
   // Calculated using torch.nn.AdaptiveAvgPool2d().
-  REQUIRE(arma::accu(output) == 19.75);
+  REQUIRE(accu(output) == 19.75);
   REQUIRE(output.n_elem == 4);
   REQUIRE(output.n_cols == 1);
   // Test the Backward Function.
   delta.set_size(12, 1);
   module1.Backward(input, output, output, delta);
-  REQUIRE(arma::accu(delta) == 19.75);
+  REQUIRE(accu(delta) == 19.75);
 
   // For Square input.
   input = arma::mat(9, 1);
@@ -71,13 +71,13 @@ TEST_CASE("AdaptiveMeanPoolingTestCase", "[ANNLayerTest]")
   module2.ComputeOutputDimensions();
   module2.Forward(input, output);
   // Calculated using torch.nn.AdaptiveAvgPool2d().
-  REQUIRE(arma::accu(output) == 4.5);
+  REQUIRE(accu(output) == 4.5);
   REQUIRE(output.n_elem == 2);
   REQUIRE(output.n_cols == 1);
   // Test the Backward Function.
   delta.set_size(9, 1);
   module2.Backward(input, output, output, delta);
-  REQUIRE(arma::accu(delta) == 4.50);
+  REQUIRE(accu(delta) == 4.50);
 
   // For Square input.
   input = arma::mat(16, 1);
@@ -95,13 +95,13 @@ TEST_CASE("AdaptiveMeanPoolingTestCase", "[ANNLayerTest]")
   module3.ComputeOutputDimensions();
   module3.Forward(input, output);
   // Calculated using torch.nn.AdaptiveAvgPool2d().
-  REQUIRE(arma::accu(output) == 10.5);
+  REQUIRE(accu(output) == 10.5);
   REQUIRE(output.n_elem == 9);
   REQUIRE(output.n_cols == 1);
   // Test the Backward Function.
   delta.set_size(16, 1);
   module3.Backward(input, output, output, delta);
-  REQUIRE(arma::accu(delta) == 10.5);
+  REQUIRE(accu(delta) == 10.5);
 
   // For Rectangular input.
   input = arma::mat(24, 1);
@@ -117,11 +117,11 @@ TEST_CASE("AdaptiveMeanPoolingTestCase", "[ANNLayerTest]")
   module4.ComputeOutputDimensions();
   module4.Forward(input, output);
   // Calculated using torch.nn.AdaptiveAvgPool2d().
-  REQUIRE(arma::accu(output) == 2.25);
+  REQUIRE(accu(output) == 2.25);
   REQUIRE(output.n_elem == 9);
   REQUIRE(output.n_cols == 1);
   // Test the Backward Function.
   delta.set_size(24, 1);
   module4.Backward(input, output, output, delta);
-  REQUIRE(arma::accu(delta) == 2.25);
+  REQUIRE(accu(delta) == 2.25);
 }
