@@ -55,7 +55,7 @@ TEST_CASE("SimpleAlphaDropoutLayerTest", "[ANNLayerTest]")
   // Test the Forward function when testing phase.
   module.Training() = false;
   module.Forward(input, output);
-  REQUIRE(arma::accu(input) == arma::accu(output));
+  REQUIRE(accu(input) == accu(output));
 }
 
 /**
@@ -108,6 +108,6 @@ TEST_CASE("NoAlphaDropoutTest", "[ANNLayerTest]")
   arma::mat output;
   module.Forward(input, output);
 
-  REQUIRE(arma::accu(output) == arma::accu(input));
+  REQUIRE(accu(output) == accu(input));
 }
 
