@@ -12,15 +12,6 @@
 #include <sstream>
 
 #include <mlpack/core.hpp>
-#include <mlpack/core/data/load_impl.hpp>
-#include <mlpack/core/data/dataset_mapper.hpp>
-#include <mlpack/core/data/map_policies/increment_policy.hpp>
-#include <mlpack/core/data/map_policies/missing_policy.hpp>
-#include <mlpack/core/data/imputer.hpp>
-#include <mlpack/core/data/imputation_methods/custom_imputation.hpp>
-#include <mlpack/core/data/imputation_methods/listwise_deletion.hpp>
-#include <mlpack/core/data/imputation_methods/mean_imputation.hpp>
-#include <mlpack/core/data/imputation_methods/median_imputation.hpp>
 
 #include "test_catch_tools.hpp"
 #include "catch.hpp"
