@@ -18,188 +18,6 @@
 
 using namespace mlpack;
 
-/**
- * Basic test of the Manhattan distance.
- */
-TEST_CASE("ManhattanDistanceTest", "[KernelTest]")
-{
-  // A couple quick tests.
-  arma::vec a = "1.0 3.0 4.0";
-  arma::vec b = "3.0 3.0 5.0";
-
-  REQUIRE(ManhattanDistance::Evaluate(a, b) == Approx(3.0).epsilon(1e-7));
-  REQUIRE(ManhattanDistance::Evaluate(b, a) == Approx(3.0).epsilon(1e-7));
-
-  // Check also for when the root is taken (should be the same).
-  REQUIRE((LMetric<1, true>::Evaluate(a, b)) == Approx(3.0).epsilon(1e-7));
-  REQUIRE((LMetric<1, true>::Evaluate(b, a)) == Approx(3.0).epsilon(1e-7));
-}
-
-/**
- * Basic test of squared Euclidean distance.
- */
-TEST_CASE("SquaredEuclideanDistanceTest", "[KernelTest]")
-{
-  // Sample 2-dimensional vectors.
-  arma::vec a = "1.0  2.0";
-  arma::vec b = "0.0 -2.0";
-
-  REQUIRE(SquaredEuclideanDistance::Evaluate(a, b) ==
-      Approx(17.0).epsilon(1e-7));
-  REQUIRE(SquaredEuclideanDistance::Evaluate(b, a) ==
-      Approx(17.0).epsilon(1e-7));
-}
-
-/**
- * Basic test of Euclidean distance.
- */
-TEST_CASE("EuclideanDistanceTest", "[KernelTest]")
-{
-  arma::vec a = "1.0 3.0 5.0 7.0";
-  arma::vec b = "4.0 0.0 2.0 0.0";
-
-  REQUIRE(EuclideanDistance::Evaluate(a, b) ==
-      Approx(sqrt(76.0)).epsilon(1e-7));
-  REQUIRE(EuclideanDistance::Evaluate(b, a) ==
-      Approx(sqrt(76.0)).epsilon(1e-7));
-}
-
-/**
- * Arbitrary test case for coverage.
- */
-TEST_CASE("ArbitraryCaseTest", "[KernelTest]")
-{
-  arma::vec a = "3.0 5.0 6.0 7.0";
-  arma::vec b = "1.0 2.0 1.0 0.0";
-
-  REQUIRE((LMetric<3, false>::Evaluate(a, b)) == Approx(503.0).epsilon(1e-7));
-  REQUIRE((LMetric<3, false>::Evaluate(b, a)) == Approx(503.0).epsilon(1e-7));
-
-  REQUIRE((LMetric<3, true>::Evaluate(a, b)) ==
-      Approx(7.95284762).epsilon(1e-7));
-  REQUIRE((LMetric<3, true>::Evaluate(b, a)) ==
-      Approx(7.95284762).epsilon(1e-7));
-}
-
-/**
- * Make sure two vectors of all zeros return zero distance, for a few different
- * powers.
- */
-TEST_CASE("LMetricZerosTest", "[KernelTest]")
-{
-  arma::vec a(250);
-  a.fill(0.0);
-
-  // We cannot use a loop because compilers seem to be unable to unroll the loop
-  // and realize the variable actually is knowable at compile-time.
-  REQUIRE(LMetric<1, false>::Evaluate(a, a) == 0);
-  REQUIRE(LMetric<1, true>::Evaluate(a, a) == 0);
-  REQUIRE(LMetric<2, false>::Evaluate(a, a) == 0);
-  REQUIRE(LMetric<2, true>::Evaluate(a, a) == 0);
-  REQUIRE(LMetric<3, false>::Evaluate(a, a) == 0);
-  REQUIRE(LMetric<3, true>::Evaluate(a, a) == 0);
-  REQUIRE(LMetric<4, false>::Evaluate(a, a) == 0);
-  REQUIRE(LMetric<4, true>::Evaluate(a, a) == 0);
-  REQUIRE(LMetric<5, false>::Evaluate(a, a) == 0);
-  REQUIRE(LMetric<5, true>::Evaluate(a, a) == 0);
-}
-
-/**
- * Simple test of Mahalanobis distance with unset covariance matrix in
- * constructor.
- */
-TEST_CASE("MDUnsetCovarianceTest", "[KernelTest]")
-{
-  MahalanobisDistance<false> md;
-  md.Covariance() = arma::eye<arma::mat>(4, 4);
-  arma::vec a = "1.0 2.0 2.0 3.0";
-  arma::vec b = "0.0 0.0 1.0 3.0";
-
-  REQUIRE(md.Evaluate(a, b) == Approx(6.0).epsilon(1e-7));
-  REQUIRE(md.Evaluate(b, a) == Approx(6.0).epsilon(1e-7));
-}
-
-/**
- * Simple test of Mahalanobis distance with unset covariance matrix in
- * constructor and t_take_root set to true.
- */
-TEST_CASE("MDRootUnsetCovarianceTest", "[KernelTest]")
-{
-  MahalanobisDistance<true> md;
-  md.Covariance() = arma::eye<arma::mat>(4, 4);
-  arma::vec a = "1.0 2.0 2.5 5.0";
-  arma::vec b = "0.0 2.0 0.5 8.0";
-
-  REQUIRE(md.Evaluate(a, b) == Approx(sqrt(14.0)).epsilon(1e-7));
-  REQUIRE(md.Evaluate(b, a) == Approx(sqrt(14.0)).epsilon(1e-7));
-}
-
-/**
- * Simple test of Mahalanobis distance setting identity covariance in
- * constructor.
- */
-TEST_CASE("MDEyeCovarianceTest", "[KernelTest]")
-{
-  MahalanobisDistance<false> md(4);
-  arma::vec a = "1.0 2.0 2.0 3.0";
-  arma::vec b = "0.0 0.0 1.0 3.0";
-
-  REQUIRE(md.Evaluate(a, b) == Approx(6.0).epsilon(1e-7));
-  REQUIRE(md.Evaluate(b, a) == Approx(6.0).epsilon(1e-7));
-}
-
-/**
- * Simple test of Mahalanobis distance setting identity covariance in
- * constructor and t_take_root set to true.
- */
-TEST_CASE("MDRootEyeCovarianceTest", "[KernelTest]")
-{
-  MahalanobisDistance<true> md(4);
-  arma::vec a = "1.0 2.0 2.5 5.0";
-  arma::vec b = "0.0 2.0 0.5 8.0";
-
-  REQUIRE(md.Evaluate(a, b) == Approx(sqrt(14.0)).epsilon(1e-7));
-  REQUIRE(md.Evaluate(b, a) == Approx(sqrt(14.0)).epsilon(1e-7));
-}
-
-/**
- * Simple test with diagonal covariance matrix.
- */
-TEST_CASE("MDDiagonalCovarianceTest", "[KernelTest]")
-{
-  arma::mat cov = arma::eye<arma::mat>(5, 5);
-  cov(0, 0) = 2.0;
-  cov(1, 1) = 0.5;
-  cov(2, 2) = 3.0;
-  cov(3, 3) = 1.0;
-  cov(4, 4) = 1.5;
-  MahalanobisDistance<false> md(cov);
-
-  arma::vec a = "1.0 2.0 2.0 4.0 5.0";
-  arma::vec b = "2.0 3.0 1.0 1.0 0.0";
-
-  REQUIRE(md.Evaluate(a, b) == Approx(52.0).epsilon(1e-7));
-  REQUIRE(md.Evaluate(b, a) == Approx(52.0).epsilon(1e-7));
-}
-
-/**
- * More specific case with more difficult covariance matrix.
- */
-TEST_CASE("MDFullCovarianceTest", "[KernelTest]")
-{
-  arma::mat cov = "1.0 2.0 3.0 4.0;"
-                  "0.5 0.6 0.7 0.1;"
-                  "3.4 4.3 5.0 6.1;"
-                  "1.0 2.0 4.0 1.0;";
-  MahalanobisDistance<false> md(cov);
-
-  arma::vec a = "1.0 2.0 2.0 4.0";
-  arma::vec b = "2.0 3.0 1.0 1.0";
-
-  REQUIRE(md.Evaluate(a, b) == Approx(15.7).epsilon(1e-7));
-  REQUIRE(md.Evaluate(b, a) == Approx(15.7).epsilon(1e-7));
-}
-
 /**
  * Simple test case for the cosine distance.
  */
