@@ -17,20 +17,19 @@
 #include "test_catch_tools.hpp"
 
 using namespace mlpack;
-using namespace mlpack::kernel;
 
 TEST_CASE("IsNormalizedTest", "[KernelTraitsTest]")
 {
   // Reason number ten billion why macros are bad:
   //
-  // The Boost unit test framework is built on macros.  When I write
+  // The Catch test framework is built on macros.  When I write
   // REQUIRE(KernelTraits<int>::IsNormalized, false) == what actually
   // happens (in gcc at least) is that the 'false' gets implicitly converted to
   // an int; then, the compiler goes looking for an int IsNormalized variable in
   // KernelTraits.  But this doesn't exist, so we get this error at linker time:
   //
   // kernel_traits_test.cpp:(.text+0xb86): undefined reference to
-  // `mlpack::kernel::KernelTraits<mlpack::kernel::LinearKernel>::IsNormalized'
+  // `KernelTraits<mlpack::kernel::LinearKernel>::IsNormalized'
   //
   // and this actually tells us nothing about the error.  When you dig deep
   // enough or get frustrated enough, you end up realizing it's a macro problem
