@@ -7,13 +7,10 @@
 
 #include <mlpack/core.hpp>
 
-#include <boost/test/unit_test.hpp>
-#include "test_tools.hpp"
+#include "catch.hpp"
 
 using namespace mlpack;
 
-BOOST_AUTO_TEST_SUITE(LogTest);
-
 /**
  * Simple log assert test. Be careful the test halts the program execution, so
  * run the test at the end of all other tests.
@@ -23,21 +20,19 @@ BOOST_AUTO_TEST_SUITE(LogTest);
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-BOOST_AUTO_TEST_CASE(LogAssertConditionTest)
+TEST_CASE("LogAssertConditionTest", "[LogTest]")
 {
   // Only do anything for Assert() if in debugging mode.
   #ifdef DEBUG
-      // If everything goes well we reach the boost test condition which is
+      // If everything goes well we reach the Catch2 test condition which is
       // always true by simplicity's sake.
       Log::Assert(true, "test");
-      BOOST_REQUIRE_EQUAL(1, 1);
+      REQUIRE(1 == 1);
 
       // The test case should halt the program execution and prints a custom
       // error message. Since the program is halted we should never reach the
-      // boost test condition which is always false by simplicity's sake.
+      // Catch2 test condition which is always false by simplicity's sake.
       // Log::Assert(false, "test");
-      // BOOST_REQUIRE_EQUAL(1, 0);
+      // REQUIRE(1 == 0);
   #endif
 }
-
-BOOST_AUTO_TEST_SUITE_END();
