@@ -3,52 +3,33 @@
  * @author Yashwant Singh
  * @author Prabhat Sharma
  *
- * Test mlpackMain() of fastmks_main.cpp.
+ * Test RUN_BINDING() of fastmks_main.cpp.
  *
  * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#include <string>
-
 #define BINDING_TYPE BINDING_TYPE_TEST
-static const std::string testName = "FastMaxKernelSearch";
 
 #include <mlpack/core.hpp>
-#include <mlpack/core/util/mlpack_main.hpp>
-#include "test_helper.hpp"
 #include <mlpack/methods/fastmks/fastmks_main.cpp>
+#include <mlpack/core/util/mlpack_main.hpp>
+#include "main_test_fixture.hpp"
 
-#include <boost/test/unit_test.hpp>
-#include "../test_tools.hpp"
+#include "../catch.hpp"
+#include "../test_catch_tools.hpp"
 
 using namespace mlpack;
 
-struct FastMKSTestFixture
-{
- public:
-  FastMKSTestFixture()
-  {
-    // Cache in the options for this program.
-    IO::RestoreSettings(testName);
-  }
-
-  ~FastMKSTestFixture()
-  {
-    // Clear the settings.
-    bindings::tests::CleanMemory();
-    IO::ClearSettings();
-  }
-};
-
-BOOST_FIXTURE_TEST_SUITE(FastMKSMainTest, FastMKSTestFixture);
+BINDING_TEST_FIXTURE(FastMKSTestFixture);
 
 /*
  * Check that we can't provide reference and query matrices
  * with different dimensions.
  */
-BOOST_AUTO_TEST_CASE(FastMKSEqualDimensionTest)
+TEST_CASE_METHOD(FastMKSTestFixture, "FastMKSEqualDimensionTest",
+                 "[FastMKSMainTest][BindingTests]")
 {
   // 100 points in 3 dimensions.
   arma::mat referenceData(3, 100, arma::fill::randu);
@@ -64,16 +45,15 @@ BOOST_AUTO_TEST_CASE(FastMKSEqualDimensionTest)
   SetInputParam("query", std::move(queryData));
   SetInputParam("k", (int) 4);
 
-  Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::invalid_argument);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::invalid_argument);
 }
 
 /*
  * Check that we can't specify an invalid k when only reference
  * matrix is given.
  */
-BOOST_AUTO_TEST_CASE(FastMKSInvalidKTest)
+TEST_CASE_METHOD(FastMKSTestFixture, "FastMKSInvalidKTest",
+                 "[FastMKSMainTest][BindingTests]")
 {
   // 50 points in 3 dimensions.
   arma::mat referenceData(3, 50, arma::fill::randu);
@@ -82,31 +62,29 @@ BOOST_AUTO_TEST_CASE(FastMKSInvalidKTest)
   SetInputParam("reference", referenceData);
   SetInputParam("k", (int) 51); // Invalid
 
-  Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::invalid_argument);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::invalid_argument);
 }
 
 /**
  * Check that when k is specified, it must be greater than 0.
  */
-BOOST_AUTO_TEST_CASE(FastMKSZeroKTest)
+TEST_CASE_METHOD(FastMKSTestFixture, "FastMKSZeroKTest",
+                 "[FastMKSMainTest][BindingTests]")
 {
   arma::mat referenceData(3, 50, arma::fill::randu);
 
   SetInputParam("reference", std::move(referenceData));
   SetInputParam("k", (int) 0); // Invalid when reference is specified.
 
-  Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /*
  * Check that we can't specify an invalid k when both reference
  * and query matrices are given.
  */
-BOOST_AUTO_TEST_CASE(FastMKSInvalidKQueryDataTest)
+TEST_CASE_METHOD(FastMKSTestFixture, "FastMKSInvalidKQueryDataTest",
+                 "[FastMKSMainTest][BindingTests]")
 {
   // 50 points in 3 dimensions.
   arma::mat referenceData(3, 50, arma::fill::randu);
@@ -118,15 +96,14 @@ BOOST_AUTO_TEST_CASE(FastMKSInvalidKQueryDataTest)
   SetInputParam("query", std::move(queryData));
   SetInputParam("k", (int) 51);
 
-  Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::invalid_argument);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::invalid_argument);
 }
 
 /*
  * Check that we can't pass both input_model and reference matrix.
  */
-BOOST_AUTO_TEST_CASE(FastMKSRefModelTest)
+TEST_CASE_METHOD(FastMKSTestFixture, "FastMKSRefModelTest",
+                 "[FastMKSMainTest][BindingTests]")
 {
   // 100 points in 3 dimensions.
   arma::mat referenceData(3, 100, arma::fill::randu);
@@ -135,23 +112,23 @@ BOOST_AUTO_TEST_CASE(FastMKSRefModelTest)
   SetInputParam("reference", referenceData);
   SetInputParam("k", (int) 10);
 
-  mlpackMain();
+  RUN_BINDING();
+
+  FastMKSModel* m = params.Get<FastMKSModel*>("output_model");
+  ResetSettings();
 
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
   SetInputParam("reference", std::move(referenceData));
   // Input pre-trained model.
-  SetInputParam("input_model",
-      std::move(IO::GetParam<FastMKSModel*>("output_model")));
+  SetInputParam("input_model", m);
 
-  Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /*
  * Check that we can't pass an invalid kernel.
  */
-BOOST_AUTO_TEST_CASE(FastMKSInvalidKernelTest)
+TEST_CASE_METHOD(FastMKSTestFixture, "FastMKSInvalidKernelTest",
+                 "[FastMKSMainTest][BindingTests]")
 {
   // 100 points in 3 dimensions.
   arma::mat referenceData(3, 100, arma::fill::randu);
@@ -162,16 +139,15 @@ BOOST_AUTO_TEST_CASE(FastMKSInvalidKernelTest)
   SetInputParam("k", (int) 10);
   SetInputParam("kernel", std::move(kernelName)); // Invalid.
 
-  Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
  * Make sure that dimensions of the indices and kernel
  * matrices are correct given a value of k.
  */
-BOOST_AUTO_TEST_CASE(FastMKSOutputDimensionTest)
+TEST_CASE_METHOD(FastMKSTestFixture, "FastMKSOutputDimensionTest",
+                 "[FastMKSMainTest][BindingTests]")
 {
   // 100 points in 3 dimensions.
   arma::mat referenceData(3, 100, arma::fill::randu);
@@ -180,23 +156,22 @@ BOOST_AUTO_TEST_CASE(FastMKSOutputDimensionTest)
   SetInputParam("reference", std::move(referenceData));
   SetInputParam("k", (int) 10);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check the indices matrix has 10 points for each input point.
-  BOOST_REQUIRE_EQUAL(IO::GetParam<arma::Mat<size_t>>
-      ("indices").n_rows, 10);
-  BOOST_REQUIRE_EQUAL(IO::GetParam<arma::Mat<size_t>>
-      ("indices").n_cols, 100);
+  REQUIRE(params.Get<arma::Mat<size_t>>("indices").n_rows == 10);
+  REQUIRE(params.Get<arma::Mat<size_t>>("indices").n_cols == 100);
 
   // Check the kernel matrix has 10 points for each input point.
-  BOOST_REQUIRE_EQUAL(IO::GetParam<arma::mat>("kernels").n_rows, 10);
-  BOOST_REQUIRE_EQUAL(IO::GetParam<arma::mat>("kernels").n_cols, 100);
+  REQUIRE(params.Get<arma::mat>("kernels").n_rows == 10);
+  REQUIRE(params.Get<arma::mat>("kernels").n_cols == 100);
 }
 
 /**
  * Ensure that saved model can be used again.
  */
-BOOST_AUTO_TEST_CASE(FastMKSModelReuseTest)
+TEST_CASE_METHOD(FastMKSTestFixture, "FastMKSModelReuseTest",
+                 "[FastMKSMainTest][BindingTests]")
 {
   // 100 points in 3 dimensions.
   arma::mat referenceData(3, 100, arma::fill::randu);
@@ -207,36 +182,35 @@ BOOST_AUTO_TEST_CASE(FastMKSModelReuseTest)
   SetInputParam("reference", std::move(referenceData));
   SetInputParam("query", queryData);
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Mat<size_t> indices;
   arma::mat kernel;
   FastMKSModel* output_model;
-  indices = std::move(IO::GetParam<arma::Mat<size_t>>("indices"));
-  kernel = std::move(IO::GetParam<arma::mat>("kernels"));
-  output_model = std::move(IO::GetParam<FastMKSModel*>("output_model"));
+  indices = std::move(params.Get<arma::Mat<size_t>>("indices"));
+  kernel = std::move(params.Get<arma::mat>("kernels"));
+  output_model = std::move(params.Get<FastMKSModel*>("output_model"));
 
-  // Reset passed parameters.
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  IO::GetSingleton().Parameters()["query"].wasPassed = false;
+  ResetSettings();
 
   // Input saved model, pass the same query and keep k unchanged.
   SetInputParam("input_model", output_model);
   SetInputParam("query", queryData);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that initial output matrices and the output matrices using
   // saved model are equal.
-  CheckMatrices(indices, IO::GetParam<arma::Mat<size_t>>("indices"));
-  CheckMatrices(kernel, IO::GetParam<arma::mat>("kernels"));
+  CheckMatrices(indices, params.Get<arma::Mat<size_t>>("indices"));
+  CheckMatrices(kernel, params.Get<arma::mat>("kernels"));
 }
 
 /*
  * Ensure that reference dataset gives the same result when passed as
  * a query dataset
  */
-BOOST_AUTO_TEST_CASE(FastMKSQueryRefTest)
+TEST_CASE_METHOD(FastMKSTestFixture, "FastMKSQueryRefTest",
+                 "[FastMKSMainTest][BindingTests]")
 {
   // 100 points in 3 dimensions.
   arma::mat referenceData(3, 100, arma::fill::randu);
@@ -245,34 +219,31 @@ BOOST_AUTO_TEST_CASE(FastMKSQueryRefTest)
   SetInputParam("query", referenceData);
   SetInputParam("k", (int) 10);
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Mat<size_t> indices;
   arma::mat kernel;
-  indices = std::move(IO::GetParam<arma::Mat<size_t>>("indices"));
-  kernel = std::move(IO::GetParam<arma::mat>("kernels"));
-
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  IO::GetSingleton().Parameters()["query"].wasPassed = false;
+  indices = std::move(params.Get<arma::Mat<size_t>>("indices"));
+  kernel = std::move(params.Get<arma::mat>("kernels"));
 
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("reference", referenceData);
   SetInputParam("query", referenceData);
+  SetInputParam("k", (int) 10);
 
-  mlpackMain();
+  RUN_BINDING();
 
-  CheckMatrices(indices,
-      IO::GetParam<arma::Mat<size_t>>("indices"));
-  CheckMatrices(kernel,
-      IO::GetParam<arma::mat>("kernels"));
+  CheckMatrices(indices, params.Get<arma::Mat<size_t>>("indices"));
+  CheckMatrices(kernel, params.Get<arma::mat>("kernels"));
 }
 
 /*
  * Ensure that naive mode returns the same result as tree mode.
  */
-BOOST_AUTO_TEST_CASE(FastMKSNaiveModeTest)
+TEST_CASE_METHOD(FastMKSTestFixture, "FastMKSNaiveModeTest",
+                 "[FastMKSMainTest][BindingTests]")
 {
   // 100 points in 3 dimensions.
   arma::mat referenceData(3, 100, arma::fill::randu);
@@ -281,35 +252,32 @@ BOOST_AUTO_TEST_CASE(FastMKSNaiveModeTest)
   SetInputParam("reference", referenceData);
   SetInputParam("k", (int) 10);
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Mat<size_t> indices;
   arma::mat kernel;
-  indices = std::move(IO::GetParam<arma::Mat<size_t>>("indices"));
-  kernel = std::move(IO::GetParam<arma::mat>("kernels"));
+  indices = std::move(params.Get<arma::Mat<size_t>>("indices"));
+  kernel = std::move(params.Get<arma::mat>("kernels"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  IO::GetSingleton().Parameters()["k"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   // Random input, some k <= number of reference points.
   SetInputParam("reference", referenceData);
   SetInputParam("k", (int) 10);
   SetInputParam("naive", true);
 
-  mlpackMain();
+  RUN_BINDING();
 
-  CheckMatrices(indices,
-      IO::GetParam<arma::Mat<size_t>>("indices"));
-  CheckMatrices(kernel,
-      IO::GetParam<arma::mat>("kernels"));
+  CheckMatrices(indices, params.Get<arma::Mat<size_t>>("indices"));
+  CheckMatrices(kernel, params.Get<arma::mat>("kernels"));
 }
 
 /*
  * Ensure that single-tree search returns the same result as dual-tree search.
  */
-BOOST_AUTO_TEST_CASE(FastMKSTreeTest)
+TEST_CASE_METHOD(FastMKSTestFixture, "FastMKSTreeTest",
+                 "[FastMKSMainTest][BindingTests]")
 {
   // 100 points in 3 dimensions.
   arma::mat referenceData(3, 100, arma::fill::randu);
@@ -318,35 +286,32 @@ BOOST_AUTO_TEST_CASE(FastMKSTreeTest)
   SetInputParam("reference", referenceData);
   SetInputParam("k", (int) 10);
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Mat<size_t> indices;
   arma::mat kernel;
-  indices = std::move(IO::GetParam<arma::Mat<size_t>>("indices"));
-  kernel = std::move(IO::GetParam<arma::mat>("kernels"));
+  indices = std::move(params.Get<arma::Mat<size_t>>("indices"));
+  kernel = std::move(params.Get<arma::mat>("kernels"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  IO::GetSingleton().Parameters()["k"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("reference", std::move(referenceData));
   SetInputParam("k", (int) 10);
   SetInputParam("single", true);
 
-  mlpackMain();
+  RUN_BINDING();
 
-  CheckMatrices(indices,
-      IO::GetParam<arma::Mat<size_t>>("indices"));
-  CheckMatrices(kernel,
-      IO::GetParam<arma::mat>("kernels"));
+  CheckMatrices(indices, params.Get<arma::Mat<size_t>>("indices"));
+  CheckMatrices(kernel, params.Get<arma::mat>("kernels"));
 }
 
 /*
  * Ensure that we get almost same results in cover tree search mode when
  * different basis is specified.
  */
-BOOST_AUTO_TEST_CASE(FastMKSBasisTest)
+TEST_CASE_METHOD(FastMKSTestFixture, "FastMKSBasisTest",
+                 "[FastMKSMainTest][BindingTests]")
 {
   // 100 points in 3 dimensions.
   arma::mat referenceData(3, 100, arma::fill::randu);
@@ -356,28 +321,26 @@ BOOST_AUTO_TEST_CASE(FastMKSBasisTest)
   SetInputParam("k", (int) 10);
   SetInputParam("base", 3.0);
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Mat<size_t> indices;
   arma::mat kernel;
-  indices = std::move(IO::GetParam<arma::Mat<size_t>>("indices"));
-  kernel = std::move(IO::GetParam<arma::mat>("kernels"));
+  indices = std::move(params.Get<arma::Mat<size_t>>("indices"));
+  kernel = std::move(params.Get<arma::mat>("kernels"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  IO::GetSingleton().Parameters()["k"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("reference", std::move(referenceData));
   SetInputParam("k", (int) 10);
   SetInputParam("base", 4.0);
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Mat<size_t> newindices;
   arma::mat newkernel;
-  newindices = std::move(IO::GetParam<arma::Mat<size_t>>("indices"));
-  newkernel = std::move(IO::GetParam<arma::mat>("kernels"));
+  newindices = std::move(params.Get<arma::Mat<size_t>>("indices"));
+  newkernel = std::move(params.Get<arma::mat>("kernels"));
 
   CheckMatrices(indices, newindices);
   CheckMatrices(kernel, newkernel);
@@ -386,7 +349,8 @@ BOOST_AUTO_TEST_CASE(FastMKSBasisTest)
 /**
  * Check that we can't specify base less than 1.
  */
-BOOST_AUTO_TEST_CASE(FastMKSBaseTest)
+TEST_CASE_METHOD(FastMKSTestFixture, "FastMKSBaseTest",
+                 "[FastMKSMainTest][BindingTests]")
 {
   // 100 points in 3 dimensions.
   arma::mat referenceData(3, 100, arma::fill::randu);
@@ -396,15 +360,14 @@ BOOST_AUTO_TEST_CASE(FastMKSBaseTest)
   SetInputParam("k", (int) 10);
   SetInputParam("base", 0.0); // Invalid.
 
-  Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
  * Ensure that different kernels returns different results.
  */
-BOOST_AUTO_TEST_CASE(FastMKSKernelTest)
+TEST_CASE_METHOD(FastMKSTestFixture, "FastMKSKernelTest",
+                 "[FastMKSMainTest][BindingTests]")
 {
   std::string kerneltypes[] = {"polynomial", "cosine", "gaussian",
       "epanechnikov", "triangular", "hyptan"};
@@ -418,7 +381,7 @@ BOOST_AUTO_TEST_CASE(FastMKSKernelTest)
   // For Hyptan Kernel
   arma::mat inputData;
   if (!data::Load("data_3d_mixed.txt", inputData))
-    BOOST_FAIL("Cannot load test dataset data_3d_ind.txt!");
+    FAIL("Cannot load test dataset data_3d_ind.txt!");
 
   arma::Mat<size_t> indicesCompare;
   arma::mat kernelsCompare;
@@ -443,173 +406,164 @@ BOOST_AUTO_TEST_CASE(FastMKSKernelTest)
       SetInputParam("query", queryData);
       SetInputParam("kernel", kerneltypes[i]);
     }
-    mlpackMain();
+    RUN_BINDING();
 
     if (i == 0)
     {
       indicesCompare =
-         std::move(IO::GetParam<arma::Mat<size_t>>("indices"));
-      kernelsCompare = std::move(IO::GetParam<arma::mat>("kernels"));
+         std::move(params.Get<arma::Mat<size_t>>("indices"));
+      kernelsCompare = std::move(params.Get<arma::mat>("kernels"));
     }
     else
     {
-      indices = std::move(IO::GetParam<arma::Mat<size_t>>("indices"));
-      kernels = std::move(IO::GetParam<arma::mat>("kernels"));
+      indices = std::move(params.Get<arma::Mat<size_t>>("indices"));
+      kernels = std::move(params.Get<arma::mat>("kernels"));
 
       CheckMatricesNotEqual(indicesCompare, indices);
       CheckMatricesNotEqual(kernelsCompare, kernels);
     }
 
     // Reset passed parameters.
-    IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-    IO::GetSingleton().Parameters()["query"].wasPassed = false;
-    IO::GetSingleton().Parameters()["kernel"].wasPassed = false;
+    ResetSettings();
 
     if (i != nofkerneltypes - 1)
-      bindings::tests::CleanMemory();
+      CleanMemory();
   }
 }
 
 /**
  * Ensure that offset affects the final result of polynomial and hyptan kernel.
  */
-BOOST_AUTO_TEST_CASE(FastMKSOffsetTest)
+TEST_CASE_METHOD(FastMKSTestFixture, "FastMKSOffsetTest",
+                 "[FastMKSMainTest][BindingTests]")
 {
   // 100 points in 3 dimensions.
   arma::mat referenceData(3, 100, arma::fill::randu);
   // Random input, some k <= number of reference points.
   SetInputParam("reference", referenceData);
   SetInputParam("k", (int) 10);
-  SetInputParam("kernel", (string)"polynomial");
+  SetInputParam("kernel", (string) "polynomial");
   SetInputParam("offset", 1.0);
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::mat polyKernel;
-  polyKernel = std::move(IO::GetParam<arma::mat>("kernels"));
+  polyKernel = std::move(params.Get<arma::mat>("kernels"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  IO::GetSingleton().Parameters()["offset"].wasPassed = false;
-  IO::GetParam<FastMKSModel*>("input_model") = NULL;
-  IO::GetParam<FastMKSModel*>("output_model") = NULL;
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("reference", referenceData);
+  SetInputParam("k", (int) 10);
+  SetInputParam("kernel", (string) "polynomial");
   SetInputParam("offset", 4.0);
 
-  mlpackMain();
+  RUN_BINDING();
 
-  CheckMatricesNotEqual(polyKernel,
-      IO::GetParam<arma::mat>("kernels"));
+  CheckMatricesNotEqual(polyKernel, params.Get<arma::mat>("kernels"));
 
-  bindings::tests::CleanMemory();
+  CleanMemory();
 
   arma::mat inputData;
   if (!data::Load("data_3d_mixed.txt", inputData))
-    BOOST_FAIL("Cannot load test dataset data_3d_ind.txt!");
+    FAIL("Cannot load test dataset data_3d_ind.txt!");
 
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  IO::GetSingleton().Parameters()["kernel"].wasPassed = false;
-  IO::GetSingleton().Parameters()["offset"].wasPassed = false;
-  IO::GetParam<FastMKSModel*>("input_model") = NULL;
-  IO::GetParam<FastMKSModel*>("output_model") = NULL;
+  ResetSettings();
 
   SetInputParam("reference", inputData);
-  SetInputParam("kernel", (std::string)"hyptan");
+  SetInputParam("k", (int) 10);
+  SetInputParam("kernel", (std::string) "hyptan");
   SetInputParam("offset", 1.0);
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::mat hyptanKernel;
-  hyptanKernel = std::move(IO::GetParam<arma::mat>("kernels"));
+  hyptanKernel = std::move(params.Get<arma::mat>("kernels"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  IO::GetSingleton().Parameters()["offset"].wasPassed = false;
-  IO::GetParam<FastMKSModel*>("input_model") = NULL;
-  IO::GetParam<FastMKSModel*>("output_model") = NULL;
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("reference", inputData);
+  SetInputParam("k", (int) 10);
+  SetInputParam("kernel", (std::string) "hyptan");
   SetInputParam("offset", 4.0);
-  mlpackMain();
+  RUN_BINDING();
 
-  CheckMatricesNotEqual(hyptanKernel,
-      IO::GetParam<arma::mat>("kernels"));
+  CheckMatricesNotEqual(hyptanKernel, params.Get<arma::mat>("kernels"));
 }
 
 /**
  * Ensure that degree affects the final result of polynomial kernel.
  */
-BOOST_AUTO_TEST_CASE(FastMKSDegreeTest)
+TEST_CASE_METHOD(FastMKSTestFixture, "FastMKSDegreeTest",
+                 "[FastMKSMainTest][BindingTests]")
 {
   // 100 points in 3 dimensions.
   arma::mat referenceData(3, 100, arma::fill::randu);
   // Random input, some k <= number of reference points.
   SetInputParam("reference", referenceData);
   SetInputParam("k", (int) 10);
-  SetInputParam("kernel", (string)"polynomial");
+  SetInputParam("kernel", (string) "polynomial");
   SetInputParam("degree", 2.0); // Default value.
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::mat polyKernel;
-  polyKernel = std::move(IO::GetParam<arma::mat>("kernels"));
+  polyKernel = std::move(params.Get<arma::mat>("kernels"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  IO::GetSingleton().Parameters()["degree"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("reference", referenceData);
+  SetInputParam("k", (int) 10);
+  SetInputParam("kernel", (string) "polynomial");
   SetInputParam("degree", 4.0);
 
-  mlpackMain();
+  RUN_BINDING();
 
-  CheckMatricesNotEqual(polyKernel,
-      IO::GetParam<arma::mat>("kernels"));
+  CheckMatricesNotEqual(polyKernel, params.Get<arma::mat>("kernels"));
 }
 
 /**
  * Ensure that scale affects the final result of hyptan kernel.
  */
-BOOST_AUTO_TEST_CASE(FastMKSScaleTest)
+TEST_CASE_METHOD(FastMKSTestFixture, "FastMKSScaleTest",
+                 "[FastMKSMainTest][BindingTests]")
 {
   arma::mat inputData;
   if (!data::Load("data_3d_mixed.txt", inputData))
-    BOOST_FAIL("Cannot load test dataset data_3d_ind.txt!");
+    FAIL("Cannot load test dataset data_3d_ind.txt!");
 
   // Random input, some k <= number of reference points.
   SetInputParam("reference", inputData);
   SetInputParam("k", (int) 10);
-  SetInputParam("kernel", (std::string)"hyptan");
+  SetInputParam("kernel", (std::string) "hyptan");
   SetInputParam("scale", 1.0); // Default value.
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::mat hyptanKernel;
-  hyptanKernel = std::move(IO::GetParam<arma::mat>("kernels"));
+  hyptanKernel = std::move(params.Get<arma::mat>("kernels"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  IO::GetSingleton().Parameters()["scale"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("reference", inputData);
+  SetInputParam("k", (int) 10);
+  SetInputParam("kernel", (std::string) "hyptan");
   SetInputParam("scale", 1.5);
 
-  mlpackMain();
+  RUN_BINDING();
 
-  CheckMatricesNotEqual(hyptanKernel,
-      IO::GetParam<arma::mat>("kernels"));
+  CheckMatricesNotEqual(hyptanKernel, params.Get<arma::mat>("kernels"));
 }
 
 /**
  * Ensure that bandwidth affects the final result of Gaussian, Epanechnikov, and
  * triangular kernel.
  */
-BOOST_AUTO_TEST_CASE(FastMKSBandwidthTest)
+TEST_CASE_METHOD(FastMKSTestFixture, "FastMKSBandwidthTest",
+                 "[FastMKSMainTest][BindingTests]")
 {
   // 100 points in 3 dimensions.
   arma::mat referenceData(3, 100, arma::fill::randu);
@@ -617,82 +571,73 @@ BOOST_AUTO_TEST_CASE(FastMKSBandwidthTest)
   // Random input, some k <= number of reference points.
   SetInputParam("reference", referenceData);
   SetInputParam("k", (int) 10);
-  SetInputParam("kernel", (string)"gaussian");
+  SetInputParam("kernel", (string) "gaussian");
   SetInputParam("bandwidth", 1.0); // Default value.
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::mat gaussianKernel;
-  gaussianKernel = std::move(IO::GetParam<arma::mat>("kernels"));
+  gaussianKernel = std::move(params.Get<arma::mat>("kernels"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  IO::GetSingleton().Parameters()["bandwidth"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("reference", referenceData);
+  SetInputParam("k", (int) 10);
+  SetInputParam("kernel", (string) "gaussian");
   SetInputParam("bandwidth", 4.0);
 
-  mlpackMain();
-  CheckMatricesNotEqual(gaussianKernel,
-      IO::GetParam<arma::mat>("kernels"));
+  RUN_BINDING();
+  CheckMatricesNotEqual(gaussianKernel, params.Get<arma::mat>("kernels"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  IO::GetSingleton().Parameters()["bandwidth"].wasPassed = false;
-  IO::GetSingleton().Parameters()["kernel"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   // Random input, some k <= number of reference points.
   SetInputParam("reference", referenceData);
-  SetInputParam("kernel", (string)"epanechnikov");
+  SetInputParam("k", (int) 10);
+  SetInputParam("kernel", (string) "epanechnikov");
   SetInputParam("bandwidth", 1.0); // Default value.
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::mat epanKernel;
-  epanKernel = std::move(IO::GetParam<arma::mat>("kernels"));
+  epanKernel = std::move(params.Get<arma::mat>("kernels"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  IO::GetSingleton().Parameters()["bandwidth"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("reference", referenceData);
+  SetInputParam("k", (int) 10);
+  SetInputParam("kernel", (string) "epanechnikov");
   SetInputParam("bandwidth", 4.0);
 
-  mlpackMain();
-  CheckMatricesNotEqual(epanKernel,
-       IO::GetParam<arma::mat>("kernels"));
+  RUN_BINDING();
+  CheckMatricesNotEqual(epanKernel, params.Get<arma::mat>("kernels"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  IO::GetSingleton().Parameters()["bandwidth"].wasPassed = false;
-  IO::GetSingleton().Parameters()["kernel"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   // Random input, some k <= number of reference points.
   SetInputParam("reference", referenceData);
-  SetInputParam("kernel", (string)"triangular");
+  SetInputParam("k", (int) 10);
+  SetInputParam("kernel", (string) "triangular");
   SetInputParam("bandwidth", 1.0); // Default value.
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::mat triKernel;
-  triKernel = std::move(IO::GetParam<arma::mat>("kernels"));
+  triKernel = std::move(params.Get<arma::mat>("kernels"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  IO::GetSingleton().Parameters()["bandwidth"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("reference", referenceData);
+  SetInputParam("k", (int) 10);
+  SetInputParam("kernel", (string) "triangular");
   SetInputParam("bandwidth", 4.0);
 
-  mlpackMain();
+  RUN_BINDING();
 
-  CheckMatricesNotEqual(triKernel,
-      IO::GetParam<arma::mat>("kernels"));
+  CheckMatricesNotEqual(triKernel, params.Get<arma::mat>("kernels"));
 }
-
-BOOST_AUTO_TEST_SUITE_END();
