@@ -2,82 +2,61 @@
  * @file tests/main_tests/linear_svm_test.cpp
  * @author Yashwant Singh Parihar
  *
- * Test mlpackMain() of logistic_regression_main.cpp
+ * Test RUN_BINDING() of logistic_regression_main.cpp
  *
  * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#include <string>
-
 #define BINDING_TYPE BINDING_TYPE_TEST
 
-static const std::string testName = "LinearSVM";
-
 #include <mlpack/core.hpp>
 #include <mlpack/methods/linear_svm/linear_svm_main.cpp>
 #include <mlpack/core/util/mlpack_main.hpp>
-#include "test_helper.hpp"
 
-#include <boost/test/unit_test.hpp>
-#include "../test_tools.hpp"
+#include "main_test_fixture.hpp"
+
+#include "../catch.hpp"
+#include "../test_catch_tools.hpp"
 
 using namespace mlpack;
 
-struct LinearSVMTestFixture
-{
- public:
-  LinearSVMTestFixture()
-  {
-    // Cache in the options for this program.
-    IO::RestoreSettings(testName);
-  }
-
-  ~LinearSVMTestFixture()
-  {
-    // Clear the settings.
-    bindings::tests::CleanMemory();
-    IO::ClearSettings();
-  }
-};
-
-BOOST_FIXTURE_TEST_SUITE(LinearSVMMainTest,
-                         LinearSVMTestFixture);
+BINDING_TEST_FIXTURE(LinearSVMTestFixture);
 
 /**
  * Ensure that trainingSet are necessarily passed when training.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMNoTrainingData)
+TEST_CASE_METHOD(LinearSVMTestFixture, "LinearSVMNoTrainingData",
+                 "[LinearSVMMainTest][BindingTests]")
 {
   arma::Row<size_t> trainLabels;
   if (!data::Load("iris_labels.txt", trainLabels))
-    BOOST_FAIL("Cannot load test dataset iris_labels.txt!");
+    FAIL("Cannot load test dataset iris_labels.txt!");
 
   SetInputParam("labels", std::move(trainLabels));
 
   // Training data is not provided. Should throw a runtime error.
-  Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
  * Checking that that size and dimensionality of prediction is correct.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMOutputDimensionTest)
+TEST_CASE_METHOD(LinearSVMTestFixture, "LinearSVMOutputDimensionTest",
+                 "[LinearSVMMainTest][BindingTests]")
 {
   arma::mat trainData;
   if (!data::Load("iris.csv", trainData))
-    BOOST_FAIL("Cannot load test dataset iris.csv!");
+    FAIL("Cannot load test dataset iris.csv!");
 
   arma::Row<size_t> trainLabels;
   if (!data::Load("iris_labels.txt", trainLabels))
-    BOOST_FAIL("Cannot load test dataset iris_labels.txt!");
+    FAIL("Cannot load test dataset iris_labels.txt!");
 
   arma::mat testData;
   if (!data::Load("iris_test.csv", testData))
-    BOOST_FAIL("Cannot load test dataset iris_test.csv!");
+    FAIL("Cannot load test dataset iris_test.csv!");
 
   size_t testSize = testData.n_cols;
 
@@ -86,44 +65,44 @@ BOOST_AUTO_TEST_CASE(LinearSVMOutputDimensionTest)
   SetInputParam("test", std::move(testData));
 
   // Training the model.
-  mlpackMain();
+  RUN_BINDING();
 
   // Get the output predictions of the test data.
   const arma::Row<size_t>& testLabels =
-      IO::GetParam<arma::Row<size_t>>("predictions");
+      params.Get<arma::Row<size_t>>("predictions");
 
   // Output predictions size must match the test data set size.
-  BOOST_REQUIRE_EQUAL(testLabels.n_rows, 1);
-  BOOST_REQUIRE_EQUAL(testLabels.n_cols, testSize);
+  REQUIRE(testLabels.n_rows == 1);
+  REQUIRE(testLabels.n_cols == testSize);
 }
 
 /**
  * Ensuring that the labels size is checked.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMCheckLabelsSizeTest)
+TEST_CASE_METHOD(LinearSVMTestFixture, "LinearSVMCheckLabelsSizeTest",
+                 "[LinearSVMMainTest][BindingTests]")
 {
   arma::mat trainData;
   if (!data::Load("iris.csv", trainData))
-    BOOST_FAIL("Cannot load test dataset iris.csv!");
+    FAIL("Cannot load test dataset iris.csv!");
 
   arma::Row<size_t> trainLabels;
   if (!data::Load("vc2_labels.txt", trainLabels))
-    BOOST_FAIL("Cannot load test dataset vc2_labels.txt!");
+    FAIL("Cannot load test dataset vc2_labels.txt!");
 
   SetInputParam("training", std::move(trainData));
   SetInputParam("labels", std::move(trainLabels));
 
   // Labels with incorrect size. It should throw a runtime error.
-  Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
  * Checking two options of specifying labels (extra row in train matrix and
  * extra parameter) and ensuring that predictions are the same.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMLabelsRepresentationTest)
+TEST_CASE_METHOD(LinearSVMTestFixture, "LinearSVMLabelsRepresentationTest",
+                 "[LinearSVMMainTest][BindingTests]")
 {
   arma::mat trainData1({{1.0, 2.0, 3.0}, {1.0, 4.0, 9.0}, {0, 1, 1}});
   arma::mat testData({{4.0, 5.0}, {1.0, 6.0}});
@@ -132,17 +111,16 @@ BOOST_AUTO_TEST_CASE(LinearSVMLabelsRepresentationTest)
   SetInputParam("test", testData);
 
   // The first solution.
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
   // Get the output.
   const arma::Row<size_t> testLabels1 =
-      std::move(IO::GetParam<arma::Row<size_t>>("predictions"));
+      std::move(params.Get<arma::Row<size_t>>("predictions"));
 
   // Reset the settings.
-  bindings::tests::CleanMemory();
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  CleanMemory();
+  ResetSettings();
 
   // Now train by providing labels as extra parameter.
   arma::mat trainData2({{1.0, 2.0, 3.0}, {1.0, 4.0, 9.0}});
@@ -153,12 +131,12 @@ BOOST_AUTO_TEST_CASE(LinearSVMLabelsRepresentationTest)
   SetInputParam("test", std::move(testData));
 
   // The second solution.
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
   // get the output
   const arma::Row<size_t>& testLabels2 =
-      IO::GetParam<arma::Row<size_t>>("predictions");
+      params.Get<arma::Row<size_t>>("predictions");
 
   // Both solutions should be equal.
   CheckMatrices(testLabels1, testLabels2);
@@ -167,48 +145,49 @@ BOOST_AUTO_TEST_CASE(LinearSVMLabelsRepresentationTest)
 /**
  * Ensure that saved model can be used again.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMModelReuseTest)
+TEST_CASE_METHOD(LinearSVMTestFixture, "LinearSVMModelReuseTest",
+                 "[LinearSVMMainTest][BindingTests]")
 {
   arma::mat trainData;
   if (!data::Load("iris.csv", trainData))
-    BOOST_FAIL("Cannot load test dataset iris.csv!");
+    FAIL("Cannot load test dataset iris.csv!");
 
   arma::Row<size_t> trainLabels;
   if (!data::Load("iris_labels.txt", trainLabels))
-    BOOST_FAIL("Cannot load test dataset iris_labels.txt!");
+    FAIL("Cannot load test dataset iris_labels.txt!");
 
   arma::mat testData;
   if (!data::Load("iris_test.csv", testData))
-    BOOST_FAIL("Cannot load test dataset iris_test.csv!");
+    FAIL("Cannot load test dataset iris_test.csv!");
 
   SetInputParam("training", std::move(trainData));
   SetInputParam("labels", std::move(trainLabels));
   SetInputParam("test", testData);
 
   // First solution
-  mlpackMain();
+  RUN_BINDING();
 
   // Get the output model obtained from training.
-  LinearSVMModel* model =
-      IO::GetParam<LinearSVMModel*>("output_model");
+  LinearSVMModel* model = params.Get<LinearSVMModel*>("output_model");
+  params.Get<LinearSVMModel*>("output_model") = NULL;
+
   // Get the output.
-  const arma::Row<size_t>& testLabels1 =
-      std::move(IO::GetParam<arma::Row<size_t>>("predictions"));
+  arma::Row<size_t> testLabels1 =
+      std::move(params.Get<arma::Row<size_t>>("predictions"));
 
   // Reset the data passed.
-  IO::GetSingleton().Parameters()["training"].wasPassed = false;
-  IO::GetSingleton().Parameters()["labels"].wasPassed = false;
-  IO::GetSingleton().Parameters()["test"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("input_model", model);
   SetInputParam("test", std::move(testData));
 
   // Second solution.
-  mlpackMain();
+  RUN_BINDING();
 
   // Get the output.
   const arma::Row<size_t>& testLabels2 =
-      IO::GetParam<arma::Row<size_t>>("predictions");
+      params.Get<arma::Row<size_t>>("predictions");
 
   // Both solutions should be equal.
   CheckMatrices(testLabels1, testLabels2);
@@ -217,206 +196,199 @@ BOOST_AUTO_TEST_CASE(LinearSVMModelReuseTest)
 /**
  * Checking for dimensionality of the test data set.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMCheckDimOfTestData)
+TEST_CASE_METHOD(LinearSVMTestFixture, "LinearSVMCheckDimOfTestData",
+                 "[LinearSVMMainTest][BindingTests]")
 {
   // Dimensionality of trainingSet is trainData.n_rows - 1 because labels are
   // not provided.
   arma::mat trainData;
   if (!data::Load("iris.csv", trainData))
-    BOOST_FAIL("Cannot load test dataset iris.csv!");
+    FAIL("Cannot load test dataset iris.csv!");
 
   arma::mat testData;
   if (!data::Load("iris_test.csv", testData))
-    BOOST_FAIL("Cannot load test dataset iris_test.csv!");
+    FAIL("Cannot load test dataset iris_test.csv!");
 
   SetInputParam("training", std::move(trainData));
   SetInputParam("test", std::move(testData));
 
   // Dimensionality of test data is wrong. It should throw a runtime error.
-  Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
  * Ensuring that test data dimensionality is checked when model is loaded.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMCheckDimOfTestData2)
+TEST_CASE_METHOD(LinearSVMTestFixture, "LinearSVMCheckDimOfTestData2",
+                 "[LinearSVMMainTest][BindingTests]")
 {
   // Dimensionality of trainingSet is trainData.n_rows - 1 because labels are
   // not provided.
   arma::mat trainData;
   if (!data::Load("iris.csv", trainData))
-    BOOST_FAIL("Cannot load test dataset iris.csv!");
+    FAIL("Cannot load test dataset iris.csv!");
 
   arma::mat testData;
   if (!data::Load("iris_test.csv", testData))
-    BOOST_FAIL("Cannot load test dataset iris_test.csv!");
+    FAIL("Cannot load test dataset iris_test.csv!");
 
   SetInputParam("training", std::move(trainData));
 
   // Training the model.
-  mlpackMain();
+  RUN_BINDING();
 
   // Get the output model obtained from training.
   LinearSVMModel* model =
-      IO::GetParam<LinearSVMModel*>("output_model");
+      params.Get<LinearSVMModel*>("output_model");
 
   // Reset the data passed.
-  IO::GetSingleton().Parameters()["training"].wasPassed = false;
-  IO::GetSingleton().Parameters()["labels"].wasPassed = false;
+  ResetSettings();
 
   SetInputParam("input_model", model);
   SetInputParam("test", std::move(testData));
 
   // Test data dimensionality is wrong. It should throw a runtime error.
-  Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
  * Ensuring that max iteration for optimizers is non negative.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMNonNegativeMaxIterationTest)
+TEST_CASE_METHOD(LinearSVMTestFixture, "LinearSVMNonNegativeMaxIterationTest",
+                 "[LinearSVMMainTest][BindingTests]")
 {
   arma::mat trainData;
   if (!data::Load("iris.csv", trainData))
-    BOOST_FAIL("Cannot load test dataset iris.csv!");
+    FAIL("Cannot load test dataset iris.csv!");
 
   arma::Row<size_t> trainLabels;
   if (!data::Load("iris_labels.txt", trainLabels))
-    BOOST_FAIL("Cannot load test dataset iris_labels.txt!");
+    FAIL("Cannot load test dataset iris_labels.txt!");
 
   SetInputParam("training", std::move(trainData));
   SetInputParam("labels", std::move(trainLabels));
   SetInputParam("max_iterations", int(-1));
 
   // Maximum iterations is negative. It should a runtime error.
-  Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
  * Ensuring that lambda for optimizers is non negative.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMNonNegativeLambdaTest)
+TEST_CASE_METHOD(LinearSVMTestFixture, "LinearSVMNonNegativeLambdaTest",
+                 "[LinearSVMMainTest][BindingTests]")
 {
   arma::mat trainData;
   if (!data::Load("iris.csv", trainData))
-    BOOST_FAIL("Cannot load test dataset iris.csv!");
+    FAIL("Cannot load test dataset iris.csv!");
 
   arma::Row<size_t> trainLabels;
   if (!data::Load("iris_labels.txt", trainLabels))
-    BOOST_FAIL("Cannot load test dataset iris_labels.txt!");
+    FAIL("Cannot load test dataset iris_labels.txt!");
 
   SetInputParam("training", std::move(trainData));
   SetInputParam("labels", std::move(trainLabels));
   SetInputParam("lambda", double(-0.01));
 
   // Lambda is negative. It should a runtime error.
-  Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
  * Ensuring that number of classes for optimizers is non negative.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMNonNegativeNumberOfClassesTest)
+TEST_CASE_METHOD(LinearSVMTestFixture,
+                 "LinearSVMNonNegativeNumberOfClassesTest",
+                 "[LinearSVMMainTest][BindingTests]")
 {
   arma::mat trainData;
   if (!data::Load("iris.csv", trainData))
-    BOOST_FAIL("Cannot load test dataset iris.csv!");
+    FAIL("Cannot load test dataset iris.csv!");
 
   arma::Row<size_t> trainLabels;
   if (!data::Load("iris_labels.txt", trainLabels))
-    BOOST_FAIL("Cannot load test dataset iris_labels.txt!");
+    FAIL("Cannot load test dataset iris_labels.txt!");
 
   SetInputParam("training", std::move(trainData));
   SetInputParam("labels", std::move(trainLabels));
   SetInputParam("num_classes", int(-1));
 
   // Number of classes is negative. It should a runtime error.
-  Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
  * Ensuring that tolerance is non negative.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMNonNegativeToleranceTest)
+TEST_CASE_METHOD(LinearSVMTestFixture, "LinearSVMNonNegativeToleranceTest",
+                 "[LinearSVMMainTest][BindingTests]")
 {
   arma::mat trainData;
   if (!data::Load("iris.csv", trainData))
-    BOOST_FAIL("Cannot load test dataset iris.csv!");
+    FAIL("Cannot load test dataset iris.csv!");
 
   arma::Row<size_t> trainLabels;
   if (!data::Load("iris_labels.txt", trainLabels))
-    BOOST_FAIL("Cannot load test dataset iris_labels.txt!");
+    FAIL("Cannot load test dataset iris_labels.txt!");
 
   SetInputParam("training", std::move(trainData));
   SetInputParam("labels", std::move(trainLabels));
   SetInputParam("tolerance", double(-0.01));
 
   // Tolerance is negative. It should throw a runtime error.
-  Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
  * Ensuring that delta is non negative.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMNonNegativeDeltaTest)
+TEST_CASE_METHOD(LinearSVMTestFixture, "LinearSVMNonNegativeDeltaTest",
+                 "[LinearSVMMainTest][BindingTests]")
 {
   arma::mat trainData;
   if (!data::Load("iris.csv", trainData))
-    BOOST_FAIL("Cannot load test dataset iris.csv!");
+    FAIL("Cannot load test dataset iris.csv!");
 
   arma::Row<size_t> trainLabels;
   if (!data::Load("iris_labels.txt", trainLabels))
-    BOOST_FAIL("Cannot load test dataset iris_labels.txt!");
+    FAIL("Cannot load test dataset iris_labels.txt!");
 
   SetInputParam("training", std::move(trainData));
   SetInputParam("labels", std::move(trainLabels));
   SetInputParam("delta", double(-0.01));
 
   // Delta is negative. It should throw a runtime error.
-  Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
  * Ensuring that epochs is non negative.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMNonNegativeEpochsTest)
+TEST_CASE_METHOD(LinearSVMTestFixture, "LinearSVMNonNegativeEpochsTest",
+                 "[LinearSVMMainTest][BindingTests]")
 {
   arma::mat trainData;
   if (!data::Load("iris.csv", trainData))
-    BOOST_FAIL("Cannot load test dataset iris.csv!");
+    FAIL("Cannot load test dataset iris.csv!");
 
   arma::Row<size_t> trainLabels;
   if (!data::Load("iris_labels.txt", trainLabels))
-    BOOST_FAIL("Cannot load test dataset iris_labels.txt!");
+    FAIL("Cannot load test dataset iris_labels.txt!");
 
   SetInputParam("training", std::move(trainData));
   SetInputParam("labels", std::move(trainLabels));
   SetInputParam("epochs", int(-1));
 
   // Epochs is negative. It should throw a runtime error.
-  Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
  * Ensuring that number classes must not be one.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMZeroNumberOfClassesTest)
+TEST_CASE_METHOD(LinearSVMTestFixture, "LinearSVMZeroNumberOfClassesTest",
+                 "[LinearSVMMainTest][BindingTests]")
 {
   arma::mat trainData = "2 0 0;"
                         "0 0 0;"
@@ -431,74 +403,71 @@ BOOST_AUTO_TEST_CASE(LinearSVMZeroNumberOfClassesTest)
 
   // Number of classes for optimizer is only one.
   // It should throw a invalid_argument error.
-  Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::invalid_argument);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::invalid_argument);
 }
 
 /**
  * Ensuring that Optimizer must be correct.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMOptimizerTest)
+TEST_CASE_METHOD(LinearSVMTestFixture, "LinearSVMOptimizerTest",
+                 "[LinearSVMMainTest][BindingTests]")
 {
   arma::mat trainData;
   if (!data::Load("iris.csv", trainData))
-    BOOST_FAIL("Cannot load test dataset iris.csv!");
+    FAIL("Cannot load test dataset iris.csv!");
 
   arma::Row<size_t> trainLabels;
   if (!data::Load("iris_labels.txt", trainLabels))
-    BOOST_FAIL("Cannot load test dataset iris_labels.txt!");
+    FAIL("Cannot load test dataset iris_labels.txt!");
 
   SetInputParam("training", std::move(trainData));
   SetInputParam("labels", std::move(trainLabels));
   SetInputParam("optimizer", std::string("hello"));
 
-  Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
  * Ensuring changing Maximum number of iterations changes the output model.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMDiffMaxIterationsTest)
+TEST_CASE_METHOD(LinearSVMTestFixture, "LinearSVMDiffMaxIterationsTest",
+                 "[LinearSVMMainTest][BindingTests]")
 {
   arma::mat trainData;
   if (!data::Load("iris.csv", trainData))
-    BOOST_FAIL("Cannot load test dataset iris.csv!");
+    FAIL("Cannot load test dataset iris.csv!");
 
   arma::Row<size_t> trainLabels;
   if (!data::Load("iris_labels.txt", trainLabels))
-    BOOST_FAIL("Cannot load test dataset iris_labels.txt!");
+    FAIL("Cannot load test dataset iris_labels.txt!");
 
   SetInputParam("training", trainData);
   SetInputParam("labels", trainLabels);
   SetInputParam("max_iterations", int(1));
 
   // First solution.
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
   // Get the parameters of the output model obtained after first training.
   const arma::mat parameters1 = std::move(
-      IO::GetParam<LinearSVMModel*>("output_model")->svm.Parameters());
+      params.Get<LinearSVMModel*>("output_model")->svm.Parameters());
 
   // Reset the settings.
-  bindings::tests::CleanMemory();
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("training", std::move(trainData));
   SetInputParam("labels", std::move(trainLabels));
   SetInputParam("max_iterations", int(100));
 
   // Second solution.
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
   // Get the parameters of the output model obtained after second training.
   const arma::mat& parameters2 =
-      IO::GetParam<LinearSVMModel*>("output_model")->svm.Parameters();
+      params.Get<LinearSVMModel*>("output_model")->svm.Parameters();
 
   // Both solutions should be not equal.
   CheckMatricesNotEqual(parameters1, parameters2);
@@ -507,44 +476,44 @@ BOOST_AUTO_TEST_CASE(LinearSVMDiffMaxIterationsTest)
 /**
  * Ensuring that lambda has some effects on the output.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMDiffLambdaTest)
+TEST_CASE_METHOD(LinearSVMTestFixture, "LinearSVMDiffLambdaTest",
+                 "[LinearSVMMainTest][BindingTests]")
 {
   arma::mat trainData;
   if (!data::Load("iris.csv", trainData))
-    BOOST_FAIL("Cannot load test dataset iris.csv!");
+    FAIL("Cannot load test dataset iris.csv!");
 
   arma::Row<size_t> trainLabels;
   if (!data::Load("iris_labels.txt", trainLabels))
-    BOOST_FAIL("Cannot load test dataset iris_labels.txt!");
+    FAIL("Cannot load test dataset iris_labels.txt!");
 
   SetInputParam("training", trainData);
   SetInputParam("labels", trainLabels);
   SetInputParam("lambda", double(0.001));
 
   // First solution.
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
   // Get the parameters of the output model obtained after first training.
   const arma::mat parameters1 = std::move(
-      IO::GetParam<LinearSVMModel*>("output_model")->svm.Parameters());
+      params.Get<LinearSVMModel*>("output_model")->svm.Parameters());
 
   // Reset the settings.
-  bindings::tests::CleanMemory();
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("training", std::move(trainData));
   SetInputParam("labels", std::move(trainLabels));
   SetInputParam("lambda", double(1000));
 
   // Second solution.
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
   // Get the parameters of the output model obtained after second training.
   const arma::mat& parameters2 =
-      IO::GetParam<LinearSVMModel*>("output_model")->svm.Parameters();
+      params.Get<LinearSVMModel*>("output_model")->svm.Parameters();
 
   // Both solutions should be not equal.
   CheckMatricesNotEqual(parameters1, parameters2);
@@ -553,44 +522,44 @@ BOOST_AUTO_TEST_CASE(LinearSVMDiffLambdaTest)
 /**
  * Ensuring that delta has some effects on the output.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMDiffDeltaTest)
+TEST_CASE_METHOD(LinearSVMTestFixture, "LinearSVMDiffDeltaTest",
+                 "[LinearSVMMainTest][BindingTests]")
 {
   arma::mat trainData;
   if (!data::Load("iris.csv", trainData))
-    BOOST_FAIL("Cannot load test dataset iris.csv!");
+    FAIL("Cannot load test dataset iris.csv!");
 
   arma::Row<size_t> trainLabels;
   if (!data::Load("iris_labels.txt", trainLabels))
-    BOOST_FAIL("Cannot load test dataset iris_labels.txt!");
+    FAIL("Cannot load test dataset iris_labels.txt!");
 
   SetInputParam("training", trainData);
   SetInputParam("labels", trainLabels);
   SetInputParam("delta", double(1.0));
 
   // First solution.
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
   // Get the parameters of the output model obtained after first training.
   const arma::mat parameters1 = std::move(
-      IO::GetParam<LinearSVMModel*>("output_model")->svm.Parameters());
+      params.Get<LinearSVMModel*>("output_model")->svm.Parameters());
 
   // Reset the settings.
-  bindings::tests::CleanMemory();
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("training", std::move(trainData));
   SetInputParam("labels", std::move(trainLabels));
   SetInputParam("delta", double(1000));
 
   // Second solution.
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
   // Get the parameters of the output model obtained after second training.
   const arma::mat& parameters2 =
-      IO::GetParam<LinearSVMModel*>("output_model")->svm.Parameters();
+      params.Get<LinearSVMModel*>("output_model")->svm.Parameters();
 
   // Both solutions should be not equal.
   CheckMatricesNotEqual(parameters1, parameters2);
@@ -599,43 +568,43 @@ BOOST_AUTO_TEST_CASE(LinearSVMDiffDeltaTest)
 /**
  * Ensuring that no_intercept has some effects on the output.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMDiffInterceptTest)
+TEST_CASE_METHOD(LinearSVMTestFixture, "LinearSVMDiffInterceptTest",
+                 "[LinearSVMMainTest][BindingTests]")
 {
   arma::mat trainData;
   if (!data::Load("iris.csv", trainData))
-    BOOST_FAIL("Cannot load test dataset iris.csv!");
+    FAIL("Cannot load test dataset iris.csv!");
 
   arma::Row<size_t> trainLabels;
   if (!data::Load("iris_labels.txt", trainLabels))
-    BOOST_FAIL("Cannot load test dataset iris_labels.txt!");
+    FAIL("Cannot load test dataset iris_labels.txt!");
 
   SetInputParam("training", trainData);
   SetInputParam("labels", trainLabels);
 
   // First solution.
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
   // Get the parameters of the output model obtained after first training.
   const arma::mat parameters1 = std::move(
-      IO::GetParam<LinearSVMModel*>("output_model")->svm.Parameters());
+      params.Get<LinearSVMModel*>("output_model")->svm.Parameters());
 
   // Reset the settings.
-  bindings::tests::CleanMemory();
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("training", std::move(trainData));
   SetInputParam("labels", std::move(trainLabels));
   SetInputParam("no_intercept", bool(true));
 
   // Second solution.
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
   // Get the parameters of the output model obtained after second training.
   const arma::mat& parameters2 =
-      IO::GetParam<LinearSVMModel*>("output_model")->svm.Parameters();
+      params.Get<LinearSVMModel*>("output_model")->svm.Parameters();
 
   // Both solutions should be not equal.
   CheckMatricesNotEqual(parameters1, parameters2);
@@ -645,7 +614,8 @@ BOOST_AUTO_TEST_CASE(LinearSVMDiffInterceptTest)
  * Ensuring that no_intercept has some effects on the output
  * when the optimizer is 'psgd'.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMDiffInterceptTestWithPsgd)
+TEST_CASE_METHOD(LinearSVMTestFixture, "LinearSVMDiffInterceptTestWithPsgd",
+                 "[LinearSVMMainTest][BindingTests]")
 {
   arma::mat trainData = "2 0 0;"
                         "0 0 0;"
@@ -660,21 +630,20 @@ BOOST_AUTO_TEST_CASE(LinearSVMDiffInterceptTestWithPsgd)
   SetInputParam("optimizer", std::string("psgd"));
 
   // First solution.
-  #ifdef HAS_OPENMP
+  #ifdef MLPACK_USE_OPENMP
   omp_set_num_threads(1);
   #endif
 
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
   // Get the parameters of the output model obtained after first training.
   const arma::mat parameters1 = std::move(
-      IO::GetParam<LinearSVMModel*>("output_model")->svm.Parameters());
+      params.Get<LinearSVMModel*>("output_model")->svm.Parameters());
 
   // Reset the settings.
-  bindings::tests::CleanMemory();
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("training", std::move(trainData));
   SetInputParam("labels", std::move(trainLabels));
@@ -682,16 +651,16 @@ BOOST_AUTO_TEST_CASE(LinearSVMDiffInterceptTestWithPsgd)
   SetInputParam("no_intercept", bool(true));
 
   // Second solution.
-  #ifdef HAS_OPENMP
+  #ifdef MLPACK_USE_OPENMP
   omp_set_num_threads(1);
   #endif
 
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
   // Get the parameters of the output model obtained after second training.
   const arma::mat& parameters2 =
-      IO::GetParam<LinearSVMModel*>("output_model")->svm.Parameters();
+      params.Get<LinearSVMModel*>("output_model")->svm.Parameters();
 
   // Both solutions should be not equal.
   CheckMatricesNotEqual(parameters1, parameters2);
@@ -700,15 +669,16 @@ BOOST_AUTO_TEST_CASE(LinearSVMDiffInterceptTestWithPsgd)
 /**
  * Ensuring that step size for optimizer is non negative.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMNonNegativeStepSizeTest)
+TEST_CASE_METHOD(LinearSVMTestFixture, "LinearSVMNonNegativeStepSizeTest",
+                 "[LinearSVMMainTest][BindingTests]")
 {
   arma::mat trainData;
   if (!data::Load("iris.csv", trainData))
-    BOOST_FAIL("Cannot load test dataset iris.csv!");
+    FAIL("Cannot load test dataset iris.csv!");
 
   arma::Row<size_t> trainLabels;
   if (!data::Load("iris_labels.txt", trainLabels))
-    BOOST_FAIL("Cannot load test dataset iris_labels.txt!");
+    FAIL("Cannot load test dataset iris_labels.txt!");
 
   SetInputParam("training", std::move(trainData));
   SetInputParam("labels", std::move(trainLabels));
@@ -716,15 +686,14 @@ BOOST_AUTO_TEST_CASE(LinearSVMNonNegativeStepSizeTest)
   SetInputParam("step_size", double(-0.01));
 
   // Step size for optimizer is negative. It should throw a runtime error.
-  Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
  * Ensuring that epochs has some effects on the output.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMDiffEpochsTest)
+TEST_CASE_METHOD(LinearSVMTestFixture, "LinearSVMDiffEpochsTest",
+                 "[LinearSVMMainTest][BindingTests]")
 {
   arma::mat trainData = "2 0 0;"
                         "0 0 0;"
@@ -740,21 +709,20 @@ BOOST_AUTO_TEST_CASE(LinearSVMDiffEpochsTest)
   SetInputParam("epochs", int(5));
 
   // First solution.
-  #ifdef HAS_OPENMP
+  #ifdef MLPACK_USE_OPENMP
   omp_set_num_threads(1);
   #endif
 
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
   // Get the parameters of the output model obtained after first training.
   const arma::mat parameters1 = std::move(
-      IO::GetParam<LinearSVMModel*>("output_model")->svm.Parameters());
+      params.Get<LinearSVMModel*>("output_model")->svm.Parameters());
 
   // Reset the settings.
-  bindings::tests::CleanMemory();
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("training", std::move(trainData));
   SetInputParam("labels", std::move(trainLabels));
@@ -762,16 +730,16 @@ BOOST_AUTO_TEST_CASE(LinearSVMDiffEpochsTest)
   SetInputParam("epochs", int(10));
 
   // Second solution.
-  #ifdef HAS_OPENMP
+  #ifdef MLPACK_USE_OPENMP
   omp_set_num_threads(1);
   #endif
 
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
   // Get the parameters of the output model obtained after second training.
   const arma::mat& parameters2 =
-      IO::GetParam<LinearSVMModel*>("output_model")->svm.Parameters();
+      params.Get<LinearSVMModel*>("output_model")->svm.Parameters();
 
   // Both solutions should be not equal.
   CheckMatricesNotEqual(parameters1, parameters2);
@@ -780,7 +748,8 @@ BOOST_AUTO_TEST_CASE(LinearSVMDiffEpochsTest)
 /**
  * Ensuring that Step size has some effects on the output.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMDiffStepSizeTest)
+TEST_CASE_METHOD(LinearSVMTestFixture, "LinearSVMDiffStepSizeTest",
+                 "[LinearSVMMainTest][BindingTests]")
 {
   arma::mat trainData = "2 0 0;"
                         "0 0 0;"
@@ -797,21 +766,20 @@ BOOST_AUTO_TEST_CASE(LinearSVMDiffStepSizeTest)
   SetInputParam("step_size", double(0.02));
 
   // First solution.
-  #ifdef HAS_OPENMP
+  #ifdef MLPACK_USE_OPENMP
   omp_set_num_threads(1);
   #endif
 
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
   // Get the parameters of the output model obtained after first training.
   const arma::mat parameters1 = std::move(
-      IO::GetParam<LinearSVMModel*>("output_model")->svm.Parameters());
+      params.Get<LinearSVMModel*>("output_model")->svm.Parameters());
 
   // Reset the settings.
-  bindings::tests::CleanMemory();
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("training", std::move(trainData));
   SetInputParam("labels", std::move(trainLabels));
@@ -820,16 +788,16 @@ BOOST_AUTO_TEST_CASE(LinearSVMDiffStepSizeTest)
   SetInputParam("step_size", double(1.02));
 
   // Second solution.
-  #ifdef HAS_OPENMP
+  #ifdef MLPACK_USE_OPENMP
   omp_set_num_threads(1);
   #endif
 
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
   // Get the parameters of the output model obtained after second training.
   const arma::mat& parameters2 =
-      IO::GetParam<LinearSVMModel*>("output_model")->svm.Parameters();
+      params.Get<LinearSVMModel*>("output_model")->svm.Parameters();
 
   // Both solutions should be not equal.
   CheckMatricesNotEqual(parameters1, parameters2);
@@ -838,7 +806,8 @@ BOOST_AUTO_TEST_CASE(LinearSVMDiffStepSizeTest)
 /**
  * Ensuring that tolerance has some effects on the output.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMDiffToleranceTest)
+TEST_CASE_METHOD(LinearSVMTestFixture, "LinearSVMDiffToleranceTest",
+                 "[LinearSVMMainTest][BindingTests]")
 {
   arma::mat trainData = "2 0 0;"
                         "0 0 0;"
@@ -855,21 +824,20 @@ BOOST_AUTO_TEST_CASE(LinearSVMDiffToleranceTest)
   SetInputParam("tolerance", double(1e-1));
 
   // First solution.
-  #ifdef HAS_OPENMP
+  #ifdef MLPACK_USE_OPENMP
   omp_set_num_threads(1);
   #endif
 
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
   // Get the parameters of the output model obtained after first training.
   const arma::mat parameters1 = std::move(
-      IO::GetParam<LinearSVMModel*>("output_model")->svm.Parameters());
+      params.Get<LinearSVMModel*>("output_model")->svm.Parameters());
 
   // Reset the settings.
-  bindings::tests::CleanMemory();
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("training", std::move(trainData));
   SetInputParam("labels", std::move(trainLabels));
@@ -878,16 +846,16 @@ BOOST_AUTO_TEST_CASE(LinearSVMDiffToleranceTest)
   SetInputParam("tolerance", double(1e-10));
 
   // Second solution.
-  #ifdef HAS_OPENMP
+  #ifdef MLPACK_USE_OPENMP
   omp_set_num_threads(1);
   #endif
 
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
   // Get the parameters of the output model obtained after second training.
   const arma::mat& parameters2 =
-      IO::GetParam<LinearSVMModel*>("output_model")->svm.Parameters();
+      params.Get<LinearSVMModel*>("output_model")->svm.Parameters();
 
   // Both solutions should be not equal.
   CheckMatricesNotEqual(parameters1, parameters2);
@@ -896,7 +864,8 @@ BOOST_AUTO_TEST_CASE(LinearSVMDiffToleranceTest)
 /**
  * Ensuring that lbfgs optimizer converges to a different result than psgd.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMDiffOptimizerTest)
+TEST_CASE_METHOD(LinearSVMTestFixture, "LinearSVMDiffOptimizerTest",
+                 "[LinearSVMMainTest][BindingTests]")
 {
   arma::mat trainData = "2 0 0;"
                         "0 0 0;"
@@ -911,37 +880,33 @@ BOOST_AUTO_TEST_CASE(LinearSVMDiffOptimizerTest)
   SetInputParam("optimizer", std::string("lbfgs"));
 
   // First solution.
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
   // Get the parameters of the output model obtained after first training.
   const arma::mat parameters1 = std::move(
-      IO::GetParam<LinearSVMModel*>("output_model")->svm.Parameters());
+      params.Get<LinearSVMModel*>("output_model")->svm.Parameters());
 
   // Reset the settings.
-  bindings::tests::CleanMemory();
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("training", std::move(trainData));
   SetInputParam("labels", std::move(trainLabels));
   SetInputParam("optimizer", std::string("psgd"));
 
   // Second solution.
-  #ifdef HAS_OPENMP
+  #ifdef MLPACK_USE_OPENMP
   omp_set_num_threads(1);
   #endif
 
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
   // Get the parameters of the output model obtained after second training.
   const arma::mat& parameters2 =
-      IO::GetParam<LinearSVMModel*>("output_model")->svm.Parameters();
+      params.Get<LinearSVMModel*>("output_model")->svm.Parameters();
 
   // Both solutions should be not equal.
   CheckMatricesNotEqual(parameters1, parameters2);
 }
-
-BOOST_AUTO_TEST_SUITE_END();
-
