@@ -12,21 +12,21 @@
 #ifndef MLPACK_TESTS_MAIN_TESTS_RANGE_SEARCH_TEST_UTILS_HPP
 #define MLPACK_TESTS_MAIN_TESTS_RANGE_SEARCH_TEST_UTILS_HPP
 
-#include <boost/test/unit_test.hpp>
 #include <mlpack/methods/range_search/rs_model.hpp>
 #include <mlpack/core.hpp>
 #include <mlpack/core/util/mlpack_main.hpp>
+#include "../catch.hpp"
 
 /**
- * Convert a model to a string using the text_oarchive of boost::serialization.
+ * Convert a model to a string using the text_oarchive of cereal.
  *
  * @param model RSModel to be converted to string.
  */
 inline std::string ModelToString(RSModel* model)
 {
   std::ostringstream oss;
-  boost::archive::text_oarchive oa(oss);
-  oa << model;
+  cereal::JSONOutputArchive oa(oss);
+  oa(CEREAL_POINTER(model));
   return oss.str();
 }
 
@@ -42,15 +42,15 @@ inline void CheckMatrices(std::vector<std::vector<double>>& vec1,
                           std::vector<std::vector<double>>& vec2,
                           const double tolerance = 1e-3)
 {
-  BOOST_REQUIRE_EQUAL(vec1.size() , vec2.size());
-  for (size_t i = 0; i < vec1.size(); i++)
+  REQUIRE(vec1.size()  == vec2.size());
+  for (size_t i = 0; i < vec1.size(); ++i)
   {
-    BOOST_REQUIRE_EQUAL(vec1[i].size(), vec2[i].size());
+    REQUIRE(vec1[i].size() == vec2[i].size());
     std::sort(vec1[i].begin(), vec1[i].end());
     std::sort(vec2[i].begin(), vec2[i].end());
-    for (size_t j = 0 ; j < vec1[i].size(); j++)
+    for (size_t j = 0 ; j < vec1[i].size(); ++j)
     {
-      BOOST_REQUIRE_CLOSE(vec1[i][j], vec2[i][j], tolerance);
+      REQUIRE(vec1[i][j] == Approx(vec2[i][j]).epsilon(tolerance));
     }
   }
 }
@@ -64,15 +64,15 @@ inline void CheckMatrices(std::vector<std::vector<double>>& vec1,
 inline void CheckMatrices(std::vector<std::vector<size_t>>& vec1,
                           std::vector<std::vector<size_t>>& vec2)
 {
-  BOOST_REQUIRE_EQUAL(vec1.size() , vec2.size());
-  for (size_t i = 0; i < vec1.size(); i++)
+  REQUIRE(vec1.size()  == vec2.size());
+  for (size_t i = 0; i < vec1.size(); ++i)
   {
-    BOOST_REQUIRE_EQUAL(vec1[i].size(), vec2[i].size());
+    REQUIRE(vec1[i].size() == vec2[i].size());
     std::sort(vec1[i].begin(), vec1[i].end());
     std::sort(vec2[i].begin(), vec2[i].end());
-    for (size_t j = 0; j < vec1[i].size(); j++)
+    for (size_t j = 0; j < vec1[i].size(); ++j)
     {
-      BOOST_REQUIRE_EQUAL(vec1[i][j], vec2[i][j]);
+      REQUIRE(vec1[i][j] == vec2[i][j]);
     }
   }
 }
