@@ -696,6 +696,75 @@ TEST_CASE("CubeShuffleTest", "[MathTest]")
     REQUIRE(counts[i] == data.n_slices);
 }
 
+/**
+ * Make sure shuffling cubes with ragged sequence lengths works.
+ */
+TEST_CASE("RaggedCubeShuffleTest", "[MathTest]")
+{
+  arma::cube data(3, 5, 5);
+  arma::cube labels(1, 5, 5);
+  arma::Row<size_t> lengths(5);
+
+  data.fill(-1);
+  labels.fill(-1);
+
+  for (size_t c = 0; c < lengths.n_elem; ++c)
+  {
+    lengths[c] = c;
+    for (size_t s = 0; s < lengths[c]; ++s)
+    {
+      data(0, c, s) = s;
+      data(1, c, s) = c;
+      labels(0, c, s) = c + s;
+    }
+  }
+
+  arma::cube outputData, outputLabels;
+  arma::Row<size_t> outputLengths;
+
+  ShuffleData(data, labels, lengths, outputData, outputLabels, outputLengths);
+
+  REQUIRE(outputData.n_rows == data.n_rows);
+  REQUIRE(outputData.n_cols == data.n_cols);
+  REQUIRE(outputData.n_slices == data.n_slices);
+  REQUIRE(outputLabels.n_rows == labels.n_rows);
+  REQUIRE(outputLabels.n_cols == labels.n_cols);
+  REQUIRE(outputLabels.n_slices == labels.n_slices);
+  REQUIRE(lengths.n_elem == outputLengths.n_elem);
+
+  // Make sure each column has the right number of slices
+  arma::Row<size_t> sliceCount(5);
+  for (size_t i = 0; i < outputLabels.n_cols; ++i)
+  {
+    for (size_t j = 0; j < outputLabels.n_slices; j++)
+    {
+      if (outputLabels(0, i, j) < 0) {
+        sliceCount[i] = j;
+        break;
+      }
+    }
+  }
+
+  for (size_t i = 0; i < 5; ++i)
+    REQUIRE(sliceCount[i] == outputLengths[i]);
+
+  // Make sure we only have each point once.
+  arma::Row<size_t> counts(5);
+  for (size_t c = 0; c < 5; ++c)
+  {
+    for (size_t s = 0; s < outputLengths[c]; ++s)
+    {
+      REQUIRE(outputData(0, c, s) + outputData(1, c, s)
+          == outputLabels(0, c, s));
+      REQUIRE(outputData(2, c, s) == Approx(-1.0).margin(1e-5));
+      counts[outputLengths[c]]++;
+    }
+  }
+
+  for (size_t i = 0; i < 5; ++i)
+    REQUIRE(counts[i] == i);
+}
+
 /**
  * Make sure shuffling data with weights works.
  */
