@@ -21,7 +21,7 @@ using namespace mlpack;
 
 // Test the traits on RectangleTrees.
 
-TEST_CASE("RectangleTreeTraitsTest", "[RectangleTreeTraitsTest]")
+TEST_CASE("RectangleTreeTest", "[RectangleTreeTest]")
 {
   // Children may be overlapping.
   bool b = TreeTraits<RTree<EuclideanDistance, EmptyStatistic,
@@ -37,7 +37,7 @@ TEST_CASE("RectangleTreeTraitsTest", "[RectangleTreeTraitsTest]")
 // Test to make sure the tree can be contains the correct number of points after
 // it is constructed.
 
-TEST_CASE("RectangleTreeConstructionCountTest", "[RectangleTreeTraitsTest]")
+TEST_CASE("RectangleTreeConstructionCountTest", "[RectangleTreeTest]")
 {
   arma::mat dataset;
   dataset.randu(3, 1000); // 1000 points in 3 dimensions.
@@ -45,7 +45,7 @@ TEST_CASE("RectangleTreeConstructionCountTest", "[RectangleTreeTraitsTest]")
   using TreeType = RTree<EuclideanDistance,
       NeighborSearchStat<NearestNeighborSort>, arma::mat>;
 
-  TreeType tree(dataset, 20, 6, 5, 2, 0);
+  TreeType tree(dataset, 20, 6, 5, 2);
   TreeType tree2 = tree;
 
   REQUIRE(tree.NumDescendants() == 1000);
@@ -85,7 +85,7 @@ std::vector<arma::vec*> GetAllPointsInTree(const TreeType& tree)
 // Test to ensure that none of the points in the tree are duplicates.  This,
 // combined with the above test to see how many points are in the tree, should
 // ensure that we inserted all points.
-TEST_CASE("RectangleTreeConstructionRepeatTest", "[RectangleTreeTraitsTest]")
+TEST_CASE("RectangleTreeConstructionRepeatTest", "[RectangleTreeTest]")
 {
   arma::mat dataset;
   dataset.randu(8, 1000); // 1000 points in 8 dimensions.
@@ -93,7 +93,7 @@ TEST_CASE("RectangleTreeConstructionRepeatTest", "[RectangleTreeTraitsTest]")
   using TreeType = RTree<EuclideanDistance,
       NeighborSearchStat<NearestNeighborSort>, arma::mat>;
 
-  TreeType tree(dataset, 20, 6, 5, 2, 0);
+  TreeType tree(dataset, 20, 6, 5, 2);
 
   std::vector<arma::vec*> allPoints = GetAllPointsInTree(tree);
   for (size_t i = 0; i < allPoints.size(); ++i)
@@ -213,7 +213,7 @@ void CheckHierarchy(const TreeType& tree)
 
 // Test to see if the bounds of the tree are correct. (Cover all bounds and
 // points beneath this node of the tree).
-TEST_CASE("RectangleTreeContainmentTest", "[RectangleTreeTraitsTest]")
+TEST_CASE("RectangleTreeContainmentTest", "[RectangleTreeTest]")
 {
   arma::mat dataset;
   dataset.randu(8, 1000); // 1000 points in 8 dimensions.
@@ -221,7 +221,7 @@ TEST_CASE("RectangleTreeContainmentTest", "[RectangleTreeTraitsTest]")
   using TreeType = RTree<EuclideanDistance,
       NeighborSearchStat<NearestNeighborSort>, arma::mat>;
 
-  TreeType tree(dataset, 20, 6, 5, 2, 0);
+  TreeType tree(dataset, 20, 6, 5, 2);
   CheckContainment(tree);
   CheckExactContainment(tree);
 }
@@ -258,7 +258,7 @@ void CheckFills(const TreeType& tree)
 }
 
 // Test to ensure that the minimum and maximum fills are satisfied.
-TEST_CASE("CheckMinAndMaxFills", "[RectangleTreeTraitsTest]")
+TEST_CASE("CheckMinAndMaxFills", "[RectangleTreeTest]")
 {
   arma::mat dataset;
   dataset.randu(8, 1000); // 1000 points in 8 dimensions.
@@ -266,7 +266,7 @@ TEST_CASE("CheckMinAndMaxFills", "[RectangleTreeTraitsTest]")
   using TreeType = RTree<EuclideanDistance,
       NeighborSearchStat<NearestNeighborSort>, arma::mat>;
 
-  TreeType tree(dataset, 20, 6, 5, 2, 0);
+  TreeType tree(dataset, 20, 6, 5, 2);
   CheckFills(tree);
 }
 
@@ -348,7 +348,7 @@ size_t CheckNumDescendants(const TreeType& tree)
 
 // A test to ensure that all leaf nodes are stored on the same level of the
 // tree.
-TEST_CASE("TreeBalance", "[RectangleTreeTraitsTest]")
+TEST_CASE("TreeBalance", "[RectangleTreeTest]")
 {
   arma::mat dataset;
   dataset.randu(8, 1000); // 1000 points in 8 dimensions.
@@ -356,7 +356,7 @@ TEST_CASE("TreeBalance", "[RectangleTreeTraitsTest]")
   using TreeType = RTree<EuclideanDistance,
       NeighborSearchStat<NearestNeighborSort>, arma::mat>;
 
-  TreeType tree(dataset, 20, 6, 5, 2, 0);
+  TreeType tree(dataset, 20, 6, 5, 2);
 
   REQUIRE(GetMinLevel(tree) == GetMaxLevel(tree));
   REQUIRE((int) tree.TreeDepth() == GetMinLevel(tree));
@@ -366,7 +366,7 @@ TEST_CASE("TreeBalance", "[RectangleTreeTraitsTest]")
 // delete numIter points and test that the query gives correct results.  It is
 // remotely possible that this test will give a false negative if it should
 // happen that two points are the same distance from a third point.
-TEST_CASE("PointDeletion", "[RectangleTreeTraitsTest]")
+TEST_CASE("PointDeletion", "[RectangleTreeTest]")
 {
   arma::mat dataset;
   dataset.randu(8, 1000); // 1000 points in 8 dimensions.
@@ -378,7 +378,7 @@ TEST_CASE("PointDeletion", "[RectangleTreeTraitsTest]")
 
   using TreeType = RTree<EuclideanDistance,
       NeighborSearchStat<NearestNeighborSort>, arma::mat>;
-  TreeType tree(dataset, 20, 6, 5, 2, 0);
+  TreeType tree(dataset, 20, 6, 5, 2);
 
   for (int i = 0; i < numIter; ++i)
     tree.DeletePoint(999 - i);
@@ -443,7 +443,7 @@ TEST_CASE("PointDeletion", "[RectangleTreeTraitsTest]")
 // negative if it should happen that two points are the same distance from a
 // third point.  Note that this is extremely inefficient.  You should not use
 // dynamic insertion until a better solution for resizing matrices is available.
-TEST_CASE("PointDynamicAdd", "[RectangleTreeTraitsTest]")
+TEST_CASE("PointDynamicAdd", "[RectangleTreeTest]")
 {
   const int numIter = 50;
   arma::mat dataset;
@@ -451,7 +451,7 @@ TEST_CASE("PointDynamicAdd", "[RectangleTreeTraitsTest]")
 
   using TreeType = RTree<EuclideanDistance,
       NeighborSearchStat<NearestNeighborSort>, arma::mat>;
-  TreeType tree(dataset, 20, 6, 5, 2, 0);
+  TreeType tree(dataset, 20, 6, 5, 2);
 
   // Add numIter new points to the dataset.  The tree copies the dataset, so we
   // must modify both the original dataset and the one that the tree holds.
@@ -520,7 +520,7 @@ TEST_CASE("PointDynamicAdd", "[RectangleTreeTraitsTest]")
 
 // A test to ensure that the SingleTreeTraverser is working correctly by
 // comparing its results to the results of a naive search.
-TEST_CASE("SingleTreeTraverserTest", "[RectangleTreeTraitsTest]")
+TEST_CASE("SingleTreeTraverserTest", "[RectangleTreeTest]")
 {
   arma::mat dataset;
   dataset.randu(8, 1000); // 1000 points in 8 dimensions.
@@ -531,7 +531,7 @@ TEST_CASE("SingleTreeTraverserTest", "[RectangleTreeTraitsTest]")
 
   using TreeType = RStarTree<EuclideanDistance,
       NeighborSearchStat<NearestNeighborSort>, arma::mat>;
-  TreeType rTree(dataset, 20, 6, 5, 2, 0);
+  TreeType rTree(dataset, 20, 6, 5, 2);
 
   REQUIRE(rTree.NumDescendants() == 1000);
 
@@ -560,7 +560,7 @@ TEST_CASE("SingleTreeTraverserTest", "[RectangleTreeTraitsTest]")
 
 // A test to ensure that the SingleTreeTraverser is working correctly by
 // comparing its results to the results of a naive search.
-TEST_CASE("XTreeTraverserTest", "[RectangleTreeTraitsTest]")
+TEST_CASE("XTreeTraverserTest", "[RectangleTreeTest]")
 {
   arma::mat dataset;
 
@@ -574,7 +574,7 @@ TEST_CASE("XTreeTraverserTest", "[RectangleTreeTraitsTest]")
 
   using TreeType = XTree<EuclideanDistance,
       NeighborSearchStat<NearestNeighborSort>, arma::mat>;
-  TreeType xTree(dataset, 20, 6, 5, 2, 0);
+  TreeType xTree(dataset, 20, 6, 5, 2);
 
   REQUIRE(xTree.NumDescendants() == numP);
 
@@ -601,7 +601,7 @@ TEST_CASE("XTreeTraverserTest", "[RectangleTreeTraitsTest]")
   }
 }
 
-TEST_CASE("HilbertRTreeTraverserTest", "[RectangleTreeTraitsTest]")
+TEST_CASE("HilbertRTreeTraverserTest", "[RectangleTreeTest]")
 {
   arma::mat dataset;
 
@@ -615,7 +615,7 @@ TEST_CASE("HilbertRTreeTraverserTest", "[RectangleTreeTraitsTest]")
 
   using TreeType = HilbertRTree<EuclideanDistance,
       NeighborSearchStat<NearestNeighborSort>, arma::mat>;
-  TreeType hilbertRTree(dataset, 20, 6, 5, 2, 0);
+  TreeType hilbertRTree(dataset, 20, 6, 5, 2);
 
   REQUIRE(hilbertRTree.NumDescendants() == numP);
 
@@ -679,14 +679,14 @@ void CheckHilbertOrdering(const TreeType& tree)
   }
 }
 
-TEST_CASE("HilbertRTreeOrderingTest", "[RectangleTreeTraitsTest]")
+TEST_CASE("HilbertRTreeOrderingTest", "[RectangleTreeTest]")
 {
   arma::mat dataset;
   dataset.randu(8, 1000); // 1000 points in 8 dimensions.
 
   using TreeType = HilbertRTree<EuclideanDistance,
       NeighborSearchStat<NearestNeighborSort>, arma::mat>;
-  TreeType hilbertRTree(dataset, 20, 6, 5, 2, 0);
+  TreeType hilbertRTree(dataset, 20, 6, 5, 2);
 
   CheckHilbertOrdering(hilbertRTree);
 }
@@ -719,19 +719,19 @@ void CheckDiscreteHilbertValueSync(const TreeType& tree)
   }
 }
 
-TEST_CASE("DiscreteHilbertValueSyncTest", "[RectangleTreeTraitsTest]")
+TEST_CASE("DiscreteHilbertValueSyncTest", "[RectangleTreeTest]")
 {
   arma::mat dataset;
   dataset.randu(8, 1000); // 1000 points in 8 dimensions.
 
   using TreeType = HilbertRTree<EuclideanDistance,
       NeighborSearchStat<NearestNeighborSort>, arma::mat>;
-  TreeType hilbertRTree(dataset, 20, 6, 5, 2, 0);
+  TreeType hilbertRTree(dataset, 20, 6, 5, 2);
 
   CheckDiscreteHilbertValueSync(hilbertRTree);
 }
 
-TEST_CASE("DiscreteHilbertValueTest", "[RectangleTreeTraitsTest]")
+TEST_CASE("DiscreteHilbertValueTest", "[RectangleTreeTest]")
 {
   arma::vec point01(1);
   arma::vec point02(1);
@@ -888,7 +888,7 @@ void CheckHilbertValue(const TreeType& tree)
     CheckHilbertValue(tree.Child(i));
 }
 
-TEST_CASE("HilbertRTeeCopyConstructorTest", "[RectangleTreeTraitsTest]")
+TEST_CASE("HilbertRTreeCopyConstructorTest", "[RectangleTreeTest]")
 {
   using TreeType = HilbertRTree<EuclideanDistance,
       NeighborSearchStat<NearestNeighborSort>, arma::mat>;
@@ -896,7 +896,7 @@ TEST_CASE("HilbertRTeeCopyConstructorTest", "[RectangleTreeTraitsTest]")
   arma::mat dataset;
   dataset.randu(8, 1000); // 1000 points in 8 dimensions.
 
-  TreeType tree(dataset, 20, 6, 5, 2, 0);
+  TreeType tree(dataset, 20, 6, 5, 2);
   TreeType copy(tree);
 
   CheckHilbertValue(copy);
@@ -908,7 +908,7 @@ TEST_CASE("HilbertRTeeCopyConstructorTest", "[RectangleTreeTraitsTest]")
   CheckNumDescendants(copy);
 }
 
-TEST_CASE("HilbertRTeeMoveConstructorTest", "[RectangleTreeTraitsTest]")
+TEST_CASE("HilbertRTeeMoveConstructorTest", "[RectangleTreeTest]")
 {
   using TreeType = HilbertRTree<EuclideanDistance,
       NeighborSearchStat<NearestNeighborSort>, arma::mat>;
@@ -916,7 +916,7 @@ TEST_CASE("HilbertRTeeMoveConstructorTest", "[RectangleTreeTraitsTest]")
   arma::mat dataset;
   dataset.randu(8, 1000); // 1000 points in 8 dimensions.
 
-  TreeType tree(dataset, 20, 6, 5, 2, 0);
+  TreeType tree(dataset, 20, 6, 5, 2);
   TreeType copy(std::move(tree));
 
   CheckHilbertValue(copy);
@@ -958,14 +958,14 @@ void CheckOverlap(const TreeType& tree)
 }
 
 
-TEST_CASE("RPlusTreeOverlapTest", "[RectangleTreeTraitsTest]")
+TEST_CASE("RPlusTreeOverlapTest", "[RectangleTreeTest]")
 {
   arma::mat dataset;
   dataset.randu(8, 1000); // 1000 points in 8 dimensions.
 
   using TreeType = RPlusTree<EuclideanDistance,
       NeighborSearchStat<NearestNeighborSort>, arma::mat>;
-  TreeType rPlusTree(dataset, 20, 6, 5, 2, 0);
+  TreeType rPlusTree(dataset, 20, 6, 5, 2);
 
   CheckOverlap(rPlusTree);
 
@@ -979,7 +979,7 @@ TEST_CASE("RPlusTreeOverlapTest", "[RectangleTreeTraitsTest]")
 }
 
 
-TEST_CASE("RPlusTreeTraverserTest", "[RectangleTreeTraitsTest]")
+TEST_CASE("RPlusTreeTraverserTest", "[RectangleTreeTest]")
 {
   arma::mat dataset;
 
@@ -993,7 +993,7 @@ TEST_CASE("RPlusTreeTraverserTest", "[RectangleTreeTraitsTest]")
 
   using TreeType = RPlusTree<EuclideanDistance,
       NeighborSearchStat<NearestNeighborSort>, arma::mat>;
-  TreeType rPlusTree(dataset, 20, 6, 5, 2, 0);
+  TreeType rPlusTree(dataset, 20, 6, 5, 2);
 
   REQUIRE(rPlusTree.NumDescendants() == numP);
 
@@ -1074,7 +1074,7 @@ void CheckRPlusPlusTreeBound(const TreeType& tree)
     CheckRPlusPlusTreeBound(tree.Child(i));
 }
 
-TEST_CASE("RPlusPlusTreeBoundTest", "[RectangleTreeTraitsTest]")
+TEST_CASE("RPlusPlusTreeBoundTest", "[RectangleTreeTest]")
 {
   arma::mat dataset;
   dataset.randu(8, 1000); // 1000 points in 8 dimensions.
@@ -1082,7 +1082,7 @@ TEST_CASE("RPlusPlusTreeBoundTest", "[RectangleTreeTraitsTest]")
   // Check the MinimalCoverageSweep.
   using TreeType = RPlusPlusTree<EuclideanDistance,
       NeighborSearchStat<NearestNeighborSort>, arma::mat>;
-  TreeType rPlusPlusTree(dataset, 20, 6, 5, 2, 0);
+  TreeType rPlusPlusTree(dataset, 20, 6, 5, 2);
 
   CheckRPlusPlusTreeBound(rPlusPlusTree);
 
@@ -1096,10 +1096,10 @@ TEST_CASE("RPlusPlusTreeBoundTest", "[RectangleTreeTraitsTest]")
   // Check the MinimalSplitsNumberSweep.
   using RPlusPlusTreeMinimalSplits = RectangleTree<EuclideanDistance,
       NeighborSearchStat<NearestNeighborSort>, arma::mat,
-      RPlusTreeSplit<RPlusPlusTreeSplitPolicy, MinimalCoverageSweep>,
+      RPlusTreeSplitType<RPlusPlusTreeSplitPolicy, MinimalCoverageSweep>,
       RPlusPlusTreeDescentHeuristic, RPlusPlusTreeAuxiliaryInformation>;
 
-  RPlusPlusTreeMinimalSplits rPlusPlusTree2(dataset, 20, 6, 5, 2, 0);
+  RPlusPlusTreeMinimalSplits rPlusPlusTree2(dataset, 20, 6, 5, 2);
 
   CheckRPlusPlusTreeBound(rPlusPlusTree2);
 
@@ -1107,7 +1107,7 @@ TEST_CASE("RPlusPlusTreeBoundTest", "[RectangleTreeTraitsTest]")
   REQUIRE((int) rPlusPlusTree2.TreeDepth() == GetMinLevel(rPlusPlusTree2));
 }
 
-TEST_CASE("RPlusPlusTreeTraverserTest", "[RectangleTreeTraitsTest]")
+TEST_CASE("RPlusPlusTreeTraverserTest", "[RectangleTreeTest]")
 {
   arma::mat dataset;
 
@@ -1121,7 +1121,7 @@ TEST_CASE("RPlusPlusTreeTraverserTest", "[RectangleTreeTraitsTest]")
 
   using TreeType = RPlusPlusTree<EuclideanDistance,
       NeighborSearchStat<NearestNeighborSort>, arma::mat>;
-  TreeType rPlusPlusTree(dataset, 20, 6, 5, 2, 0);
+  TreeType rPlusPlusTree(dataset, 20, 6, 5, 2);
 
   REQUIRE(rPlusPlusTree.NumDescendants() == numP);
 
@@ -1153,7 +1153,7 @@ TEST_CASE("RPlusPlusTreeTraverserTest", "[RectangleTreeTraitsTest]")
 
 // Test the tree splitting.  We set MaxLeafSize and MaxNumChildren rather low
 // to allow us to test by hand without adding hundreds of points.
-TEST_CASE("RTreeSplitTest", "[RectangleTreeTraitsTest]")
+TEST_CASE("RTreeSplitTest", "[RectangleTreeTest]")
 {
   arma::mat data = trans(arma::mat("0.0 0.0;"
                                          "0.0 1.0;"
@@ -1168,7 +1168,7 @@ TEST_CASE("RTreeSplitTest", "[RectangleTreeTraitsTest]")
 
   using TreeType = RTree<EuclideanDistance,
       NeighborSearchStat<NearestNeighborSort>, arma::mat>;
-  TreeType rTree(data, 5, 2, 2, 1, 0);
+  TreeType rTree(data, 5, 2, 2, 1);
 
   // There's technically no reason they have to be in a certain order, so we
   // use firstChild etc. to arbitrarily name them.
@@ -1248,7 +1248,7 @@ TEST_CASE("RTreeSplitTest", "[RectangleTreeTraitsTest]")
 
 // Test the tree splitting.  We set MaxLeafSize and MaxNumChildren rather low
 // to allow us to test by hand without adding hundreds of points.
-TEST_CASE("RStarTreeSplitTest", "[RectangleTreeTraitsTest]")
+TEST_CASE("RStarTreeSplitTest", "[RectangleTreeTest]")
 {
   arma::mat data = trans(arma::mat("0.0 0.0;"
                                          "0.0 1.0;"
@@ -1264,7 +1264,7 @@ TEST_CASE("RStarTreeSplitTest", "[RectangleTreeTraitsTest]")
   using TreeType = RStarTree<EuclideanDistance,
       NeighborSearchStat<NearestNeighborSort>, arma::mat>;
 
-  TreeType rTree(data, 5, 2, 2, 1, 0);
+  TreeType rTree(data, 5, 2, 2, 1);
 
   // There's technically no reason they have to be in a certain order, so we
   // use firstChild etc. to arbitrarily name them.
@@ -1339,7 +1339,7 @@ TEST_CASE("RStarTreeSplitTest", "[RectangleTreeTraitsTest]")
       Approx(0.9).epsilon(1e-17));
 }
 
-TEST_CASE("RectangleTreeMoveDatasetTest", "[RectangleTreeTraitsTest]")
+TEST_CASE("RectangleTreeMoveDatasetTest", "[RectangleTreeTest]")
 {
   arma::mat dataset = arma::randu<arma::mat>(3, 1000);
   using TreeType = RTree<EuclideanDistance, EmptyStatistic, arma::mat>;
@@ -1350,3 +1350,77 @@ TEST_CASE("RectangleTreeMoveDatasetTest", "[RectangleTreeTraitsTest]")
   REQUIRE(tree.Dataset().n_rows == 3);
   REQUIRE(tree.Dataset().n_cols == 1000);
 }
+
+// Test that points can be added to the tree.
+TEST_CASE("RectangleTreeInsertVsBatchTest", "[RectangleTreeTest]")
+{
+  // Make sure that manually inserting points gives the same tree as if we build
+  // the tree all at once.
+  arma::mat dataset = arma::randu<arma::mat>(3, 1000);
+  using TreeType = RTree<EuclideanDistance, EmptyStatistic, arma::mat>;
+
+  TreeType tree1(dataset);
+  TreeType tree2;
+  for (size_t i = 0; i < dataset.n_cols; ++i)
+    tree2.Insert(dataset.col(i));
+
+  REQUIRE(tree1.Dataset().n_cols == tree2.Dataset().n_cols);
+  REQUIRE(tree1.Dataset().n_rows == tree2.Dataset().n_rows);
+
+  // We should have the same structure, too.
+  std::stack<std::pair<TreeType*, TreeType*>> s;
+  s.push(std::make_pair(&tree1, &tree2));
+  while (!s.empty())
+  {
+    std::pair<TreeType*, TreeType*> p = s.top();
+    s.pop();
+
+    TreeType* n1 = p.first;
+    TreeType* n2 = p.second;
+
+    REQUIRE(n1->NumChildren() == n2->NumChildren());
+    REQUIRE(n1->MinNumChildren() == n2->MinNumChildren());
+    REQUIRE(n1->MaxNumChildren() == n2->MaxNumChildren());
+    REQUIRE(n1->NumDescendants() == n2->NumDescendants());
+    REQUIRE(n1->NumPoints() == n2->NumPoints());
+    REQUIRE(n1->MinLeafSize() == n2->MinLeafSize());
+    REQUIRE(n1->MaxLeafSize() == n2->MaxLeafSize());
+    for (size_t p = 0; p < n1->NumPoints(); ++p)
+      REQUIRE(n1->Point(p) == n2->Point(p));
+
+    for (size_t c = 0; c < n1->NumChildren(); ++c)
+      s.push(std::make_pair(&n1->Child(c), &n2->Child(c)));
+  }
+}
+
+// Test that points can be removed from the tree.
+TEST_CASE("RectangleTreeDeleteTest", "[RectangleTreeTest]")
+{
+  // Build a tree on a random dataset and then remove points from it one-by-one.
+  // At the end, we should have an empty tree.
+  arma::mat dataset = arma::randu<arma::mat>(3, 1000);
+  using TreeType = RTree<EuclideanDistance, EmptyStatistic, arma::mat>;
+
+  TreeType tree(dataset);
+  REQUIRE(tree.NumDescendants() == dataset.n_cols);
+
+  arma::Col<size_t> removeOrder = arma::shuffle(
+      arma::linspace<arma::Col<size_t>>(0, dataset.n_cols - 1, dataset.n_cols));
+
+  for (size_t i = 0; i < removeOrder.n_elem; ++i)
+  {
+    // We will have to adjust the index of our point, since we have removed
+    // other points first.
+    const size_t adjust = (i == 0) ? 0 :
+        arma::accu(removeOrder.subvec(0, i - 1) < removeOrder[i]);
+
+    REQUIRE((removeOrder[i] - adjust) < tree.Dataset().n_cols);
+    tree.Delete(removeOrder[i] - adjust);
+    REQUIRE(tree.NumDescendants() == (dataset.n_cols - i - 1));
+    REQUIRE(tree.Dataset().n_cols == (dataset.n_cols - i - 1));
+  }
+
+  // Now the tree should be empty.
+  REQUIRE(tree.NumDescendants() == 0);
+  REQUIRE(tree.NumPoints() == 0);
+}
