@@ -23,7 +23,7 @@ void SCVerifyCorrectness(const VecType& beta,
                          const VecType& errCorr,
                          double lambda)
 {
-  const double tol = std::is_same<typename VecType::elem_type, float>::value ?
+  const double tol = std::is_same_v<typename VecType::elem_type, float> ?
       1e-6 : 1e-12;
   size_t nDims = beta.n_elem;
   for (size_t j = 0; j < nDims; ++j)
@@ -50,8 +50,8 @@ void SCVerifyCorrectness(const VecType& beta,
 TEMPLATE_TEST_CASE("SparseCodingTestCodingStepLasso", "[SparseCodingTest]",
     arma::mat, arma::fmat)
 {
-  typedef TestType MatType;
-  typedef arma::Col<typename MatType::elem_type> VecType;
+  using MatType = TestType;
+  using VecType = arma::Col<typename MatType::elem_type>;
 
   double lambda1 = 0.1;
   uword nAtoms = 25;
@@ -84,8 +84,8 @@ TEMPLATE_TEST_CASE("SparseCodingTestCodingStepLasso", "[SparseCodingTest]",
 TEMPLATE_TEST_CASE("SparseCodingTestCodingStepElasticNet", "[SparseCodingTest]",
     arma::mat, arma::fmat)
 {
-  typedef TestType MatType;
-  typedef arma::Col<typename MatType::elem_type> VecType;
+  using MatType = TestType;
+  using VecType = arma::Col<typename MatType::elem_type>;
 
   double lambda1 = 0.1;
   double lambda2 = 0.2;
@@ -120,9 +120,9 @@ TEMPLATE_TEST_CASE("SparseCodingTestCodingStepElasticNet", "[SparseCodingTest]",
 TEMPLATE_TEST_CASE("SparseCodingTestDictionaryStep", "[SparseCodingTest]",
     arma::mat, arma::fmat)
 {
-  typedef TestType MatType;
+  using MatType = TestType;
 
-  const double tol = std::is_same<typename MatType::elem_type, float>::value ?
+  const double tol = std::is_same_v<typename MatType::elem_type, float> ?
       0.01 : 1e-6;
 
   double lambda1 = 0.1;
@@ -153,7 +153,7 @@ TEMPLATE_TEST_CASE("SparseCodingTestDictionaryStep", "[SparseCodingTest]",
 TEMPLATE_TEST_CASE("SerializationTest", "[SparseCodingTest]", arma::mat,
     arma::fmat)
 {
-  typedef TestType MatType;
+  using MatType = TestType;
 
   MatType X = randu<MatType>(100, 100);
   size_t nAtoms = 25;
@@ -213,9 +213,9 @@ TEMPLATE_TEST_CASE("SerializationTest", "[SparseCodingTest]", arma::mat,
 TEMPLATE_TEST_CASE("SparseCodingTrainReturnObjective", "[SparseCodingTest]",
     arma::mat, arma::fmat)
 {
-  typedef TestType MatType;
+  using MatType = TestType;
 
-  const double tol = std::is_same<typename MatType::elem_type, float>::value ?
+  const double tol = std::is_same_v<typename MatType::elem_type, float> ?
       0.01 : 1e-6;
 
   double lambda1 = 0.1;
